#
# spec file for package ejabberd
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%define systemuser ejabberd
%if 0%{?suse_version} > 1310
%define split_out_epmd 1
%endif
%if 0%{?suse_version} > 1140
%define have_systemd 1
%endif

%{!?_tmpfilesdir:%global _tmpfilesdir /usr/lib/tmpfiles.d}
%bcond_with    elixir
%bcond_with    redis
%bcond_with    riak
%bcond_with    sqlite
%bcond_without graphics

Name:           ejabberd
Version:        19.02
%global ejabberd_dir    %{_libdir}/%{name}-%{version}/
Release:        1.6
Summary:        A distributed, fault-tolerant Jabber/XMPP server
Group:          Productivity/Networking/Talk/Servers
License:        GPL-2.0
URL:            http://ejabberd.im/
Source0:        http://www.process-one.net/downloads/ejabberd/%{version}/ejabberd-%{version}.tgz
Source1:        ejabberd.init.suse
Source3:        ejabberd.Notes
Source4:        ejabberd.service
Source5:        ejabberd-rpmlintrc
Source6:        ejabberd-tmpfiles-.conf
Patch:          ejabberd-fix_make_install_when_using_system_deps.patch
Patch1:         ejabberd-16.01_document_optional.patch
Patch2:         ejabberd-16.06_dont_run_as_root.patch
Patch3:         ejabberd-bump-deps.patch
PreReq:         pwdutils
BuildRequires:  xz
BuildRequires:  fdupes
BuildRequires:  erlang >= 17.1
%if 0%{?split_out_empd}
BuildRequires:  erlang-epmd-devel
%endif
BuildRequires:  erlang-rebar-devel
# from rebar.config
BuildRequires:  erlang-lager-devel >= 3.6.7
%requires_eq    erlang-lager
#
BuildRequires:  erlang-p1_utils-devel >= 1.0.14
%requires_eq    erlang-p1_utils
#
BuildRequires:  erlang-p1_cache_tab-devel >= 1.0.18
%requires_eq    erlang-p1_cache_tab
#
BuildRequires:  erlang-fast_tls-devel >= 1.1.0
%requires_eq    erlang-fast_tls
#
BuildRequires:  erlang-stringprep-devel >= 1.0.15
%requires_eq    erlang-stringprep
#
BuildRequires:  erlang-fast_xml-devel >= 1.1.35
%requires_eq    erlang-fast_xml
#
BuildRequires:  erlang-xmpp-devel >= 1.3.2
%requires_eq    erlang-xmpp
#
BuildRequires:  erlang-fast_yaml-devel >= 1.0.18
%requires_eq    erlang-fast_yaml
#
BuildRequires:  erlang-jiffy-devel >= 0.14.11
%requires_eq    erlang-jiffy
#
BuildRequires:  erlang-p1_oauth2-devel >= 0.6.4
%requires_eq    erlang-p1_oauth2
#
BuildRequires:  erlang-pkix-devel >= 1.0.1
%requires_eq    erlang-pkix
#
BuildRequires:  erlang-jose-devel >= 1.8.4
%requires_eq    erlang-jose
#
%if %{with graphics}
BuildRequires:  erlang-eimp-devel >= 1.0.10
%requires_eq    erlang-eimp
%endif
#
BuildRequires:  erlang-mqtree-devel >= 1.0.2
%requires_eq    erlang-mqtree
#
BuildRequires:  erlang-stun-devel >= 1.0.27
%requires_eq    erlang-stun
#
BuildRequires:  erlang-esip-devel >= 1.0.28
%requires_eq    erlang-esip
#
BuildRequires:  erlang-p1_mysql-devel >= 1.0.9
%requires_eq    erlang-p1_mysql
#
BuildRequires:  erlang-p1_pgsql-devel >= 1.1.7
%requires_eq    erlang-p1_pgsql
#
BuildRequires:  erlang-epam-devel >= 1.0.5
%requires_eq    erlang-epam
#
BuildRequires:  erlang-ezlib-devel >= 1.0.5
%requires_eq    erlang-ezlib
#
BuildRequires:  erlang-luerl-devel >= 0.3
%requires_eq    erlang-luerl
#
%if %{with elixir}
BuildRequires:  elixir >= 1.4.5
BuildRequires:  erlang-rebar_elixir_plugin
%requires_eq    elixir
%endif
%if %{with sqlite}
BuildRequires:  sqlite-devel >= 3.6.19
BuildRequires:  erlang-sqlite3-devel >= 1.1.6
%requires_eq    erlang-sqlite3
%endif
%if %{with redis}
BuildRequires:  erlang-eredis-devel >= 1.0.8
%requires_eq    erlang-eredis
%endif
%requires_eq    erlang
%if 0%{?split_out_empd}
%requires_eq    erlang-epmd
%endif
Recommends:     ImageMagick
# needed by captcha
Recommends:     ghostscript-x11
Requires:       sudo
Requires:       inotify-tools

%if 0%{?have_systemd}
BuildRequires:  pkgconfig(systemd)
%{?systemd_requires}
%else
PreReq:         %insserv_prereq
%endif
Obsoletes:      ejabberd-contrib < 0~git1518710694
%description
ejabberd is a Free and Open Source distributed fault-tolerant
Jabber/XMPP server.

%package doc
Summary:        Documentation for ejabberd
Group:          Documentation/Other

%description doc
Documentation for ejabberd. Release Notes and User Guide

%package devel
Summary:        Development files for ejabberd
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}
%description devel
Development files for ejabberd. Use it for build ejabberd modules.

%pre
getent group %{systemuser} >/dev/null || groupadd -r %{systemuser}
getent passwd %{systemuser} >/dev/null || useradd -r -g %{systemuser} -d /var/lib/ejabberd -s /bin/false -c "user for ejabberd" %{systemuser}
%if 0%{?have_systemd}
%service_add_pre %{name}.service
%endif
exit 0

%if 0%{?have_systemd}
%post
systemd-tmpfiles --create %{_tmpfilesdir}/%{name}.conf
%service_add_post %{name}.service
%endif

%preun
%if 0%{?have_systemd}
%service_del_preun %{name}.service
%else
%stop_on_removal ejabberd
%endif

%postun
%if 0%{?have_systemd}
%service_del_postun %{name}.service
%else
%restart_on_update ejabberd
%insserv_cleanup
%endif

%prep
%setup -q
%patch  -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
perl -p -i -e 's|/lib/ejabberd/priv/bin/captcha.sh|%{ejabberd_dir}/priv/bin/captcha.sh|g' ejabberd.yml.example

%build
export REBAR_DEPS_PREFER_LIBS=1
rm -f rebar
ln -s %{_bindir}/rebar rebar
%configure \
 --enable-tools \
 --enable-odbc \
 --enable-mysql \
 --enable-pgsql \
 %if %{with sqlite}
 --enable-sqlite \
 %endif
 --enable-pam \
 --enable-zlib \
 %if %{with riak}
 --enable-riak \
 %endif
 %if %{with redis}
 --enable-redis \
 %endif
 %if %{with elixir}
 --enable-elixir \
 %endif
 --enable-iconv \
 --enable-debug \
 --enable-stun \
 --enable-sip \
 --enable-system-deps \
 --enable-user=%{systemuser} \
 --enable-group=%{systemuser} \
 --docdir=%{_docdir}/%{name}

perl -p -i -e "s|deps/p1_utils/include|$(rpm -ql erlang-p1_utils-devel | grep -E '/include$' )|g" rebar.config
perl -p -i -e "s|deps/fast_xml/include|$(rpm -ql erlang-fast_xml | grep -E '/include$' )|g" rebar.config
perl -p -i -e "s|deps/xmpp/include|$(rpm -ql erlang-xmpp-devel | grep -E '/include$' )|g"   rebar.config


%rebar compile

%install
export REBAR_DEPS_PREFER_LIBS=1
make install DESTDIR=%{buildroot} INSTALLUSER= INSTALLGROUP=
cp -av sql/mysql.sql sql/pg.sql %{buildroot}%{ejabberd_dir}/priv/sql/

mkdir -p %{buildroot}/var/log/%{name}
mkdir -p %{buildroot}/var/lib/%{name}/spool
mkdir -p %{buildroot}/var/lock/ejabberdctl
mkdir -p %{buildroot}{/var,}/run/%{name}

mkdir -p %{buildroot}%{_sbindir}

# systemd
%if 0%{?have_systemd}
install -D -m 0644  %{S:4} %{buildroot}%{_unitdir}/%{name}.service
install -D -m 0644  %{S:6} %{buildroot}%{_tmpfilesdir}/%{name}.conf
ln -s /sbin/service %{buildroot}/usr/sbin/rcejabberd
%else
# SysV
install -D %{S:1} %{buildroot}/etc/init.d/ejabberd
ln -s /etc/init.d/ejabberd %{buildroot}/usr/sbin/rcejabberd
%{__perl} -pi -e 's!\@libdir\@!%{_libdir}!g' %{buildroot}%{_initrddir}/ejabberd
%endif

cp %{S:3} %{buildroot}%{_docdir}/%{name}
touch %{buildroot}%{_sysconfdir}/ejabberd/ejabberd.cfg
mkdir -p %{buildroot}%{ejabberd_dir}/data

%fdupes -s %{buildroot}%{_docdir}/%{name}/

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%attr(750,root,%{systemuser}) %dir %{_sysconfdir}/ejabberd
%ghost %attr(640,root,%{systemuser}) %config(noreplace) %{_sysconfdir}/ejabberd/ejabberd.cfg
%attr(640,root,%{systemuser}) %config(noreplace) %{_sysconfdir}/ejabberd/ejabberd.yml
%attr(640,root,%{systemuser}) %config(noreplace) %{_sysconfdir}/ejabberd/ejabberdctl.cfg
%attr(640,root,%{systemuser}) %config(noreplace) %{_sysconfdir}/ejabberd/inetrc
%{_sbindir}/rcejabberd
%attr(755,root,root) %{_sbindir}/ejabberdctl
%if 0%{?have_systemd}
%{_unitdir}/%{name}.service
%{_tmpfilesdir}/%{name}.conf
%dir %ghost %attr(755,ejabberd,ejabberd) /run/ejabberd
%dir %ghost                              /run/lock/
%dir %ghost %attr(755,ejabberd,ejabberd) /run/lock/ejabberdctl
%else
%{_initrddir}/ejabberd
%endif
%dir %{ejabberd_dir}
%dir %{ejabberd_dir}/data
%dir %{ejabberd_dir}/ebin
%dir %{ejabberd_dir}/priv
%dir %{ejabberd_dir}/priv/bin
%dir %{ejabberd_dir}/priv/css
%dir %{ejabberd_dir}/priv/img
%dir %{ejabberd_dir}/priv/js
%dir %{ejabberd_dir}/priv/lua
%dir %{ejabberd_dir}/priv/msgs
%dir %{ejabberd_dir}/priv/sql
%{ejabberd_dir}/COPYING
%{ejabberd_dir}/ebin/acl.beam
%{ejabberd_dir}/ebin/acme_challenge.beam
#{ejabberd_dir}/ebin/cyrsasl_anonymous.beam
#{ejabberd_dir}/ebin/cyrsasl.beam
#{ejabberd_dir}/ebin/cyrsasl_digest.beam
#{ejabberd_dir}/ebin/cyrsasl_oauth.beam
#{ejabberd_dir}/ebin/cyrsasl_plain.beam
#{ejabberd_dir}/ebin/cyrsasl_scram.beam
%{ejabberd_dir}/ebin/ejabberd_access_permissions.beam
%{ejabberd_dir}/ebin/ejabberd_acme.beam
%{ejabberd_dir}/ebin/ejabberd_acme_comm.beam
%{ejabberd_dir}/ebin/ejabberd_admin.beam
%{ejabberd_dir}/ebin/ejabberd.app
%{ejabberd_dir}/ebin/ejabberd_app.beam
%{ejabberd_dir}/ebin/ejabberd_auth_anonymous.beam
%{ejabberd_dir}/ebin/ejabberd_auth.beam
%{ejabberd_dir}/ebin/ejabberd_auth_external.beam
%{ejabberd_dir}/ebin/ejabberd_auth_ldap.beam
%{ejabberd_dir}/ebin/ejabberd_auth_mnesia.beam
%{ejabberd_dir}/ebin/ejabberd_auth_pam.beam
%{ejabberd_dir}/ebin/ejabberd_auth_riak.beam
%{ejabberd_dir}/ebin/ejabberd_auth_sql.beam
%{ejabberd_dir}/ebin/ejabberd.beam
%{ejabberd_dir}/ebin/ejabberd_backend_sup.beam
%{ejabberd_dir}/ebin/ejabberd_bosh.beam
%{ejabberd_dir}/ebin/ejabberd_c2s.beam
%{ejabberd_dir}/ebin/ejabberd_c2s_config.beam
%{ejabberd_dir}/ebin/ejabberd_captcha.beam
%{ejabberd_dir}/ebin/ejabberd_cluster.beam
%{ejabberd_dir}/ebin/ejabberd_cluster_mnesia.beam
%{ejabberd_dir}/ebin/ejabberd_commands.beam
%{ejabberd_dir}/ebin/ejabberd_commands_doc.beam
%{ejabberd_dir}/ebin/ejabberd_config.beam
%{ejabberd_dir}/ebin/ejabberd_ctl.beam
%{ejabberd_dir}/ebin/ejabberd_hooks.beam
%{ejabberd_dir}/ebin/ejabberd_http.beam
%{ejabberd_dir}/ebin/ejabberd_http_ws.beam
%{ejabberd_dir}/ebin/ejabberd_iq.beam
%{ejabberd_dir}/ebin/ejabberd_listener.beam
%{ejabberd_dir}/ebin/ejabberd_local.beam
%{ejabberd_dir}/ebin/ejabberd_logger.beam
%{ejabberd_dir}/ebin/ejabberd_mnesia.beam
%{ejabberd_dir}/ebin/ejabberd_oauth.beam
%{ejabberd_dir}/ebin/ejabberd_oauth_mnesia.beam
%{ejabberd_dir}/ebin/ejabberd_oauth_rest.beam
%{ejabberd_dir}/ebin/ejabberd_oauth_sql.beam
%{ejabberd_dir}/ebin/ejabberd_piefxis.beam
%{ejabberd_dir}/ebin/ejabberd_pkix.beam
%{ejabberd_dir}/ebin/ejabberd_rdbms.beam
%{ejabberd_dir}/ebin/ejabberd_redis.beam
%{ejabberd_dir}/ebin/ejabberd_redis_sup.beam
%{ejabberd_dir}/ebin/ejabberd_regexp.beam
%{ejabberd_dir}/ebin/ejabberd_riak.beam
%{ejabberd_dir}/ebin/ejabberd_riak_sup.beam
%{ejabberd_dir}/ebin/ejabberd_router.beam
%{ejabberd_dir}/ebin/ejabberd_router_mnesia.beam
%{ejabberd_dir}/ebin/ejabberd_router_multicast.beam
%{ejabberd_dir}/ebin/ejabberd_router_redis.beam
%{ejabberd_dir}/ebin/ejabberd_router_riak.beam
%{ejabberd_dir}/ebin/ejabberd_router_sql.beam
%{ejabberd_dir}/ebin/ejabberd_shaper.beam
%{ejabberd_dir}/ebin/ejabberd_s2s.beam
%{ejabberd_dir}/ebin/ejabberd_s2s_in.beam
%{ejabberd_dir}/ebin/ejabberd_s2s_out.beam
%{ejabberd_dir}/ebin/ejabberd_service.beam
%{ejabberd_dir}/ebin/ejabberd_sip.beam
%{ejabberd_dir}/ebin/ejabberd_sm.beam
%{ejabberd_dir}/ebin/ejabberd_sm_mnesia.beam
%{ejabberd_dir}/ebin/ejabberd_sm_redis.beam
%{ejabberd_dir}/ebin/ejabberd_sm_riak.beam
%{ejabberd_dir}/ebin/ejabberd_sm_sql.beam
%{ejabberd_dir}/ebin/ejabberd_sql.beam
%{ejabberd_dir}/ebin/ejabberd_sql_pt.beam
%{ejabberd_dir}/ebin/ejabberd_sql_sup.beam
%{ejabberd_dir}/ebin/ejabberd_stun.beam
%{ejabberd_dir}/ebin/ejabberd_sup.beam
%{ejabberd_dir}/ebin/ejabberd_system_monitor.beam
%{ejabberd_dir}/ebin/ejabberd_tmp_sup.beam
%{ejabberd_dir}/ebin/ejabberd_update.beam
%{ejabberd_dir}/ebin/ejabberd_web_admin.beam
%{ejabberd_dir}/ebin/ejabberd_web.beam
%{ejabberd_dir}/ebin/ejabberd_websocket.beam
%{ejabberd_dir}/ebin/ejabberd_xmlrpc.beam
%{ejabberd_dir}/ebin/ejd2sql.beam
%{ejabberd_dir}/ebin/eldap.beam
%{ejabberd_dir}/ebin/eldap_filter.beam
%{ejabberd_dir}/ebin/eldap_filter_yecc.beam
%{ejabberd_dir}/ebin/eldap_pool.beam
%{ejabberd_dir}/ebin/eldap_utils.beam
%{ejabberd_dir}/ebin/ELDAPv3.beam
%{ejabberd_dir}/ebin/elixir_logger_backend.beam
%{ejabberd_dir}/ebin/extauth.beam
%{ejabberd_dir}/ebin/extauth_sup.beam
%{ejabberd_dir}/ebin/ext_mod.beam
%{ejabberd_dir}/ebin/gen_iq_handler.beam
%{ejabberd_dir}/ebin/gen_mod.beam
%{ejabberd_dir}/ebin/gen_pubsub_node.beam
%{ejabberd_dir}/ebin/gen_pubsub_nodetree.beam
%{ejabberd_dir}/ebin/jd2ejd.beam
%{ejabberd_dir}/ebin/misc.beam
%{ejabberd_dir}/ebin/mod_adhoc.beam
%{ejabberd_dir}/ebin/mod_admin_extra.beam
%{ejabberd_dir}/ebin/mod_admin_update_sql.beam
%{ejabberd_dir}/ebin/mod_announce.beam
%{ejabberd_dir}/ebin/mod_announce_mnesia.beam
%{ejabberd_dir}/ebin/mod_announce_riak.beam
%{ejabberd_dir}/ebin/mod_announce_sql.beam
%{ejabberd_dir}/ebin/mod_avatar.beam
%{ejabberd_dir}/ebin/mod_block_strangers.beam
%{ejabberd_dir}/ebin/mod_blocking.beam
%{ejabberd_dir}/ebin/mod_bosh.beam
%{ejabberd_dir}/ebin/mod_bosh_mnesia.beam
%{ejabberd_dir}/ebin/mod_bosh_redis.beam
%{ejabberd_dir}/ebin/mod_bosh_riak.beam
%{ejabberd_dir}/ebin/mod_bosh_sql.beam
%{ejabberd_dir}/ebin/mod_caps.beam
%{ejabberd_dir}/ebin/mod_caps_mnesia.beam
%{ejabberd_dir}/ebin/mod_caps_riak.beam
%{ejabberd_dir}/ebin/mod_caps_sql.beam
%{ejabberd_dir}/ebin/mod_carboncopy.beam
%{ejabberd_dir}/ebin/mod_client_state.beam
%{ejabberd_dir}/ebin/mod_configure.beam
%{ejabberd_dir}/ebin/mod_delegation.beam
%{ejabberd_dir}/ebin/mod_disco.beam
%{ejabberd_dir}/ebin/mod_echo.beam
%{ejabberd_dir}/ebin/mod_fail2ban.beam
%{ejabberd_dir}/ebin/mod_http_api.beam
%{ejabberd_dir}/ebin/mod_http_fileserver.beam
%{ejabberd_dir}/ebin/mod_http_upload.beam
%{ejabberd_dir}/ebin/mod_http_upload_quota.beam
%{ejabberd_dir}/ebin/mod_last.beam
%{ejabberd_dir}/ebin/mod_last_mnesia.beam
%{ejabberd_dir}/ebin/mod_last_riak.beam
%{ejabberd_dir}/ebin/mod_last_sql.beam
%{ejabberd_dir}/ebin/mod_legacy_auth.beam
%{ejabberd_dir}/ebin/mod_mam.beam
%{ejabberd_dir}/ebin/mod_mam_mnesia.beam
%{ejabberd_dir}/ebin/mod_mam_sql.beam
%{ejabberd_dir}/ebin/mod_metrics.beam
%{ejabberd_dir}/ebin/mod_mix.beam
%{ejabberd_dir}/ebin/mod_mix_mnesia.beam
%{ejabberd_dir}/ebin/mod_mix_pam.beam
%{ejabberd_dir}/ebin/mod_mix_pam_mnesia.beam
%{ejabberd_dir}/ebin/mod_mix_pam_sql.beam
%{ejabberd_dir}/ebin/mod_mix_sql.beam
%{ejabberd_dir}/ebin/mod_mqtt.beam
%{ejabberd_dir}/ebin/mod_mqtt_mnesia.beam
%{ejabberd_dir}/ebin/mod_mqtt_session.beam
%{ejabberd_dir}/ebin/mod_mqtt_sql.beam
%{ejabberd_dir}/ebin/mod_muc_admin.beam
%{ejabberd_dir}/ebin/mod_muc.beam
%{ejabberd_dir}/ebin/mod_muc_log.beam
%{ejabberd_dir}/ebin/mod_muc_mnesia.beam
%{ejabberd_dir}/ebin/mod_muc_riak.beam
%{ejabberd_dir}/ebin/mod_muc_room.beam
%{ejabberd_dir}/ebin/mod_muc_sql.beam
%{ejabberd_dir}/ebin/mod_multicast.beam
%{ejabberd_dir}/ebin/mod_offline.beam
%{ejabberd_dir}/ebin/mod_offline_mnesia.beam
%{ejabberd_dir}/ebin/mod_offline_riak.beam
%{ejabberd_dir}/ebin/mod_offline_sql.beam
%{ejabberd_dir}/ebin/mod_ping.beam
%{ejabberd_dir}/ebin/mod_pres_counter.beam
%{ejabberd_dir}/ebin/mod_privacy.beam
%{ejabberd_dir}/ebin/mod_privacy_mnesia.beam
%{ejabberd_dir}/ebin/mod_privacy_riak.beam
%{ejabberd_dir}/ebin/mod_privacy_sql.beam
%{ejabberd_dir}/ebin/mod_private.beam
%{ejabberd_dir}/ebin/mod_private_mnesia.beam
%{ejabberd_dir}/ebin/mod_private_riak.beam
%{ejabberd_dir}/ebin/mod_private_sql.beam
%{ejabberd_dir}/ebin/mod_proxy65.beam
%{ejabberd_dir}/ebin/mod_proxy65_lib.beam
%{ejabberd_dir}/ebin/mod_proxy65_mnesia.beam
%{ejabberd_dir}/ebin/mod_proxy65_redis.beam
%{ejabberd_dir}/ebin/mod_proxy65_riak.beam
%{ejabberd_dir}/ebin/mod_proxy65_service.beam
%{ejabberd_dir}/ebin/mod_proxy65_sql.beam
%{ejabberd_dir}/ebin/mod_proxy65_stream.beam
%{ejabberd_dir}/ebin/mod_privilege.beam
%{ejabberd_dir}/ebin/mod_pubsub.beam
%{ejabberd_dir}/ebin/mod_push.beam
%{ejabberd_dir}/ebin/mod_push_keepalive.beam
%{ejabberd_dir}/ebin/mod_push_mnesia.beam
%{ejabberd_dir}/ebin/mod_push_sql.beam
%{ejabberd_dir}/ebin/mod_register.beam
%{ejabberd_dir}/ebin/mod_register_web.beam
%{ejabberd_dir}/ebin/mod_roster.beam
%{ejabberd_dir}/ebin/mod_roster_mnesia.beam
%{ejabberd_dir}/ebin/mod_roster_riak.beam
%{ejabberd_dir}/ebin/mod_roster_sql.beam
%{ejabberd_dir}/ebin/mod_s2s_dialback.beam
%{ejabberd_dir}/ebin/mod_service_log.beam
%{ejabberd_dir}/ebin/mod_shared_roster.beam
%{ejabberd_dir}/ebin/mod_shared_roster_ldap.beam
%{ejabberd_dir}/ebin/mod_shared_roster_mnesia.beam
%{ejabberd_dir}/ebin/mod_shared_roster_riak.beam
%{ejabberd_dir}/ebin/mod_shared_roster_sql.beam
%{ejabberd_dir}/ebin/mod_sic.beam
%{ejabberd_dir}/ebin/mod_sip.beam
%{ejabberd_dir}/ebin/mod_sip_proxy.beam
%{ejabberd_dir}/ebin/mod_sip_registrar.beam
%{ejabberd_dir}/ebin/mod_stats.beam
%{ejabberd_dir}/ebin/mod_stream_mgmt.beam
%{ejabberd_dir}/ebin/mod_time.beam
%{ejabberd_dir}/ebin/mod_vcard.beam
%{ejabberd_dir}/ebin/mod_vcard_ldap.beam
%{ejabberd_dir}/ebin/mod_vcard_mnesia.beam
%{ejabberd_dir}/ebin/mod_vcard_riak.beam
%{ejabberd_dir}/ebin/mod_vcard_sql.beam
%{ejabberd_dir}/ebin/mod_vcard_xupdate.beam
%{ejabberd_dir}/ebin/mod_version.beam
%{ejabberd_dir}/ebin/mqtt_codec.beam
%{ejabberd_dir}/ebin/node_buddy.beam
%{ejabberd_dir}/ebin/node_club.beam
%{ejabberd_dir}/ebin/node_dag.beam
%{ejabberd_dir}/ebin/node_dispatch.beam
%{ejabberd_dir}/ebin/node_flat.beam
%{ejabberd_dir}/ebin/node_flat_sql.beam
%{ejabberd_dir}/ebin/node_hometree.beam
%{ejabberd_dir}/ebin/node_hometree_sql.beam
%{ejabberd_dir}/ebin/node_mb.beam
%{ejabberd_dir}/ebin/node_mb_sql.beam
%{ejabberd_dir}/ebin/node_mix.beam
%{ejabberd_dir}/ebin/node_mix_sql.beam
%{ejabberd_dir}/ebin/node_online.beam
%{ejabberd_dir}/ebin/node_pep.beam
%{ejabberd_dir}/ebin/node_pep_sql.beam
%{ejabberd_dir}/ebin/node_private.beam
%{ejabberd_dir}/ebin/node_public.beam
%{ejabberd_dir}/ebin/nodetree_dag.beam
%{ejabberd_dir}/ebin/nodetree_tree.beam
%{ejabberd_dir}/ebin/nodetree_tree_sql.beam
%{ejabberd_dir}/ebin/nodetree_virtual.beam
%{ejabberd_dir}/ebin/prosody2ejabberd.beam
%{ejabberd_dir}/ebin/proxy_protocol.beam
%{ejabberd_dir}/ebin/pubsub_db_sql.beam
%{ejabberd_dir}/ebin/pubsub_index.beam
%{ejabberd_dir}/ebin/pubsub_migrate.beam
%{ejabberd_dir}/ebin/pubsub_subscription.beam
%{ejabberd_dir}/ebin/pubsub_subscription_sql.beam
%{ejabberd_dir}/ebin/rest.beam
%{ejabberd_dir}/ebin/str.beam
%{ejabberd_dir}/ebin/translate.beam
%{ejabberd_dir}/ebin/win32_dns.beam
%{ejabberd_dir}/ebin/xml_compress.beam
%{ejabberd_dir}/ebin/xml_compress_gen.beam
%{ejabberd_dir}/priv/css/*.css
%{ejabberd_dir}/priv/img/*
%{ejabberd_dir}/priv/js/*
%{ejabberd_dir}/priv/lua/*
%{ejabberd_dir}/priv/msgs/*.msg
%{ejabberd_dir}/priv/sql/lite.sql
%{ejabberd_dir}/priv/sql/mysql.sql
%{ejabberd_dir}/priv/sql/pg.sql
%attr(750,root,%{systemuser}) %{ejabberd_dir}/priv/bin/*.sh
%attr(750,%{systemuser},%{systemuser}) %dir /var/lib/ejabberd
%attr(750,%{systemuser},%{systemuser}) %dir /var/lib/ejabberd/spool
%attr(750,%{systemuser},%{systemuser}) %dir /var/log/ejabberd
%if ! 0%{?have_systemd}
%attr(750,%{systemuser},%{systemuser}) %dir /var/lock/ejabberdctl
%attr(750,%{systemuser},%{systemuser}) %dir /var/run/ejabberd
%endif
%dir %{_docdir}/%{name}/
%{_docdir}/%{name}/COPYING

%files devel
%defattr(-,root,root,-)
%{ejabberd_dir}/include

%files doc
%defattr(644,root,root,755)
%{_docdir}/%{name}/ejabberd.Notes

%changelog
* Mon Mar  4 2019 Marcus Rueckert <mrueckert@suse.de>
- update to 19.02
  https://blog.process-one.net/ejabberd-19-02-the-mqtt-edition/
  https://blog.process-one.net/ejabberd-18-12-1/
  https://blog.process-one.net/ejabberd-18-12/
- refresh patches
  ejabberd-bump-deps.patch
  ejabberd-fix_make_install_when_using_system_deps.patch
* Sun Nov 11 2018 Marcus Rueckert <mrueckert@suse.de>
- update to 18.09
  - Default configuration – Simplify the default configuration file
    – Enable Roster Versioning in the default config file – Enable
    TLS by default (and require it for c2s) – Use “localhost” as a
    default host – Increased default ‘max_stanza_size’ limit for
    c2s listener from 65536 to 262144 – Set a default
    ‘max_stanza_size’ for incoming s2s listener: 524288 – Remove
    vcard search default value – Remove mod_stats and mod_time from
    default config
  - Logging – Improve error formatting – Switch more log message to
    warning level – Don’t hide ‘undef’ exceptions during config
    validation – Fail early when loading unavailable SIP or STUN
    modules – Report real address of a listener – Fix stacktrace
    call by getting it out of lager context – Log message on
    incoming s2s connection close – Better format invalid values
    when logging them – Only lookup FQDN at configuration
    (re)loading
  - Commands – muc_invite hook now also receives the Packet as
    argument – Recognize more non-atom fields in format_room_option
    – send_message command triggers hook for user_send_packet –
    Remove num_active_users as it uses calls to last_activity
    mnesia table
  - Dependencies – Move XMPP stream and SASL processing to xmpp
    repo – Move randoms module to p1_utils repo – Move shaper to
    p1_utils repo – Fix misc:try_url for erlang = 3.2.0
  - Core – Refactor ejabberd_listener source code and API – Fix
    regression: list SASL EXTERNAL mechanism for inbound s2s –
    Disable cache for anonymous auth backend – Improve URLs
    validation
  - Databases – Resize SQL pool on configuration reload – MySQL:
    Use MEDIUMTEXT for MAM/offline messages – fix for freetds UTF-8
    corruption – Fix piefxis import of vCard and privacy lists –
    Lua script for cleaning redis sessions – Add ODBC connection
    robustness
  - HTTP Upload – Log error if ‘put_url’ is reused – Adjust default
    value of ‘put_url’ – Deprecate ‘service_url’ option – Add
    “Allow” to OPTIONS response – Avoid timers from timer module –
    Don’t store “external” slots – Treat file and network errors
    differently – Introduce new option ‘external_secret’ – Increase
    gen_server call timeout – Put more info in log messages –
    mod_http_upload_quota: Fix process name lookup
  - MUC – Allow an occupant owner/admin to kick lower-affiliation
    moderator – mod_muc_room: Fix the room’s CAPS hash: include
    xdata – Fix max_user_conferences in Mnesia to consider only one
    MUC service – mod_muc: Don’t set default for
    muc#roomconfig_lang – mod_muc: Increase ‘max_user_conferences’
    default from 10 to 100 – Reload internal room’s configuration
    when mod_muc is reloaded
  - MUC/Sub – In response with list of room subscriptions include
    also events – Add information about real sender to mucsub
    message meta – Allow a subscribed owner/admin to kick
    lower-affiliation moderator – Allow a subscribed owner/admin to
    kick participants and visitors – Allow a subscribed owner/admin
    to change participant / visitor
  - Other modules – BOSH: Wait for more data than just before
    sending – BOSH: Make sure that we always start inactivity timer
    from drop_holding_receiver – MAM: Don’t strip offline message
    stanza IDs – MAM: Make sure stanza IDs aren’t reused –
    mod_muc_log: Support both filenames and URLs in ‘cssfile’
    option – mod_ping: Don’t stop sending pings when receiving
    timeout for timeout_action=none – mod_proxy65: Don’t ignore
    send() result – mod_proxy65: Increase default buffer size for
    mod_proxy65 – PubSub: Correctly handle empty result with RSM –
    PubSub: Enforce pubsub option required/rejected attributes –
    mod_register_web: Handle ejabberd_captcha error reports
- refreshed patches
  ejabberd-16.01_document_optional.patch
  ejabberd-bump-deps.patch
  ejabberd-fix_make_install_when_using_system_deps.patch
* Sat Jun 30 2018 mrueckert@suse.de
- obsolete ejabberd-contrib. barely any modules are building at the
  moment.
* Sat Jun 30 2018 mrueckert@suse.de
- update to 18.06
  https://blog.process-one.net/ejabberd-18-06/
  Stop ejabberd initialization on invalid/unknown options Since
  some time now, we are warning ejabberd admins in log file about
  incorrect configuration options. We feel that we are ready to
  make these hints strong requirements about config file validity.
  Starting with ejabberd 18.06, ejabberd will not ignore unknown
  options and doesn’t allow to have options with malformed values.
  The rationale for this is to avoid unexpected behaviour during
  runtime, i.e. to conform to “fail early” approach. We thus hope
  to be helpful to newcomers by making sure they properly format
  their config files to get the expected behaviour.
  Note that it’s safe to reload a configuration with potentially
  invalid and/or unknown options: this will not halt ejabberd, but
  will only prevent the configuration from loading.
- refreshed patches:
  ejabberd-16.01_document_optional.patch
  ejabberd-bump-deps.patch
  ejabberd-fix_make_install_when_using_system_deps.patch
* Wed Mar 28 2018 mrueckert@suse.de
- remove skip_deps=true from the rebar cmdline
- no longer use --enable-graphics
- also pass the runtime group
* Wed Mar 28 2018 mrueckert@suse.de
- enforce eimp 1.0.4
* Tue Mar 27 2018 mrueckert@suse.de
- update to 18.03
  https://blog.process-one.net/ejabberd-18-03/
- refreshed patches:
  ejabberd-16.01_document_optional.patch
  ejabberd-bump-deps.patch
  ejabberd-fix_make_install_when_using_system_deps.patch
* Thu Mar  8 2018 mrueckert@suse.de
- move to /run/ejabberd
* Mon Feb  5 2018 mrueckert@suse.de
- update to 18.01
  https://blog.process-one.net/ejabberd-18-01/
  - Fix TLS driver memory management
  - Fix privacy_set command
  - Report ‘fs’ support as unavailable on SunOS
  - Let mod_block_strangers bounce an error when a message is
    rejected
* Sat Dec 30 2017 mrueckert@suse.de
- update to 17.12
  https://blog.process-one.net/ejabberd-17-12/
  - SNI for inbound connections Server Name Indication (SNI for
    short) is a way for clients to provide a server name for the
    certificate intended to use for TLS connection. There is a
    trend to replace STARTTLS (defined in RFC6120) with the new
    approach defined in XEP-0368 (also known as “Direct-TLS”). This
    is where SNI becomes useful: there is no need now to do
    STARTTLS, instead, a client may directly open a TLS connection
    to a server and request the server’s certificate via SNI
    extension. Such approach makes it possible to multiplex several
    services on a single port (e.g. having both XMPP and HTTP on
    port 443) and, for huge deployments, to offload SSL to
    frontends, such as nginx or haproxy.
  - Rewrite ejabberd system monitor Previous version was
    inefficient making its usage almost pointless, but with a lot
    of potential. The new verion is based on memsup(3erl)
    application: the OOM watchdog is only started when total OS
    memory consumption is more than 80%%. A watchdog periodically
    inspects all running processes and collects statistics about
    overloaded ones. If the OOM killer is enabled (with ejabberd
    option oom_killer: true), all overloaded processes would be
    killed. By default, OOM killer is enabled. When memory
    consumption is back to normal, the OOM watchdog is stopped.
  - Support PubSub v1.14 and OMEMO Missing features and behaviour
    has been discussed with users of the Conversations client, to
    improve support of OMEMO and fix the blocking items.
  - Improvements A race in join_cluster has been fixed,
    inotifywait.exe on Windows has been fixed, ODBC configuration
    on Windows has been fixed, logger is killed and restarted when
    it’s overloaded, certificate creation and validation chain has
    been optimised for faster operation.  Certificates management
    has been improved and binary installer now provides “ready to
    use” and pre-configured ones.
  - Changes
  - Core
  - Rewrite ejabberd system monitor for efficiency
  - Fix incoming XMPP processing order
  - Use xmpp:try_subtag/2 wherever possible
  - Better process subtag decoding errors
  - Only allow compression after SASL as per XEP-0170
  - Don’t crash on unexpected XML events
  - Fix session mnesia table cleanup
  - Don’t let privacy list prevent local roster update
  - Encryption
  - Rely on Server Name Indication for incoming Direct-TLS
    connections
  - Speedup certificate chains creation and validation
  - Log warning on empty wildcard paths
  - Don’t call pkix_is_self_signed/1 too frequently
  - Eat less memory during building certificates graph
  - Avoid infinite loop between self-signed certs
  - Fix function clause on filelib:wildcard/1
  - Use ejabberd_pkix API in mod_sip
  - Move ‘certfile’ based options in a single place
  - Groupchat
  - Don’t crash on malformed IQ
  - Include x tag in presence errors related to nick change
  - Include 110 status on shutdown
  - Improve muc#roominfo and muc#roomconfig forms
  - mod_mam: Never store MUC messages in user archives
  - PubSub
  - Fix num_subscribers on node metadata
  - Fix send last items on initial presence
  - Send last PEP items to owner on initial presence
  - Support pubsub#publish-options PRECONDITIONs
  - Add pubsub#multi-items to features list (Support XEP-0060
    v1.14)
  - Add missing Nidx building records from sql result
  - Don’t force RSM in get_items when max_items is not provided
  - Admin
  - Introduce option ‘ca_file’
  - Set executable permission on mac_listener when installing
  - Use /bin/sh as the explicit shell when using su in
    ejabberdctl.
  - Logging
  - Change loglevel of TLS failures
  - Log a warning when a disk is almost full
  - Disable default alarm handler
  - Handle also process_memory_high_watermark alarm
  - Kill and restart lager when it’s overloaded
  - Avoid excessive logging of SQL failures
  - Commands
  - New muc_online_room_by_regex command
  - Fix race between join_cluster and ejabberd_mnesia
  - Fix commands rooms_unused_list and _destroy
  - send_direct_invitations accepts only user jids
  - ejabberd_sm: Fix get_session_sid/3
  - SQL
  - Add missing server_host column in pg.new.sql
  - Add new schema for MySQL and Sqlite
  - Fix SQL serialization
- refresh patches:
  ejabberd-16.01_document_optional.patch
  ejabberd-bump-deps.patch
  ejabberd-fix_make_install_when_using_system_deps.patch
* Fri Nov 24 2017 mrueckert@suse.de
- require inotify-tools for this letsencrypt support
* Thu Nov 23 2017 mrueckert@suse.de
- update to 17.11
  https://blog.process-one.net/ejabberd-17-11-happy-birthday-ejabberd/
  - Admin
  - Omit “ProtectSystem” option from systemd unit
  - Log warnings for c2s/s2s certfile option
  - Log a message when a user gets registered
  - ejabberdctl: Fix ‘read’ syntax for non-bash shells
  - Fix renew_certificates ejabberdctl command
  - Unregister commands when stopping node only if it’s last one
  - Halt ejabberd if the top supervisor fails to start
  - Build
  - Avoid badarg error when running get-deps before ./configure
    has created src/ejabberd.app
  - Fix sed invocation that was incompatible with FreeBSD’s sed
  - Makefile.in: Fix “make clean && make”
  - Improve –enable-system-deps
  - Install binaries with 755 permissions
  - Install eimp binary with +x attribute
  - Remove find-outdated-deps script, we have better replacement
    for it
  - Databases
  - Allow export command regardless of the configured db_type
  - Add SQL_INSERT macro and update SQL queries to use
    server_host field
  - Update SQL archive index to match mysql.sql
  - mod_muc: Use correct table field name in sql query
  - MAM
  - Always strip stanza IDs
  - Announce support for stanza IDs
  - Don’t store from ‘sm_receive_packet’ hook
  - Fix mod_mam reloading
  - Ignore non-message stanzas earlier
  - Improve handling of forked messages
  - Make sure a stanza ID is always added
  - Make sure archived message isn’t bounced
  - Prepare version 0.6.1 of XEP-0313 (MAM) support
  - MUC
  - Properly store subject element
  - Resend presences and history if presence possesses x MUC
    element
  - Send presence-unavailable when expulsing a participant
  - Add mucsub event for subscribers list changes
  - Optimize muc subscriptions handling
  - Show real jid in mucsub subscription change events
  - PubSub
  - Add basic PubSub meta-data support
  - Rewrite pubsub export to sql
  - Cleanup tree requests, rename pubsub_node.type to
    pubsub_node.plugin
  - Fix select_type race on plugin_init
  - Implement parentnodes seek for hometree
  - Delete cached item on node removal
  - Fix delete item from unregistered user
  - Cleanup pubsub subscriptions quering, fix pep case
  - PEP services must send notifications to the account owner
  - Push
  - Avoid notification duplicates
  - Add support for SQL storage
  - Add export from Mnesia database to SQL file
  - Don’t store xdata() in Mnesia table
  - Simplify backend interface
  - Miscelanea
  - Mix _xmpp-server and _xmpps-server SRV records (XEP-0368)
  - HTTP: Don’t crash when Host header is missing
  - HTTP fileserver: Accept routes in Host header and map them to
    vhosts
  - mod_register_web: Better handle mobile devices in CSS
  - mod_stream_mgmt: Improve logging on timeout
  - mod_stream_mgmt: Increase ‘max_ack_queue’ default
  - Updated Catalan, Chinese, Czech, French, Galician, German,
    Greek, Hebrew, Russian, Spanish translations
  - WebAdmin: Don’t include CSS, javascript and image data
    directly in the code
- refresh patches to apply cleanly again:
  ejabberd-16.01_document_optional.patch
  ejabberd-16.06_dont_run_as_root.patch
  ejabberd-bump-deps.patch
  ejabberd-fix_make_install_when_using_system_deps.patch
* Mon Nov  6 2017 mrueckert@suse.de
- enable graphics
* Sat Nov  4 2017 mrueckert@suse.de
- update to 17.09
  https://blog.process-one.net/ejabberd-17-09/
  - Admin
  - Harden ejabberdctl
  - Fix ejabberdctl quoting when using iex
  - Call earlier deps configure scripts during compilation
  - Fix iexdebug and iexlive commands
  - Quote $PEER in ping command to avoid hostnames containing “-”
    being interpreted as arithmetic
  - Docker: Sync containers from rroemhild and add instructions
    in README
  - Use eimp instead of ImageMagick calls for thumbnails creation
  - Add forgotten caching options to the validator
  - Fix ‘make install’ to work with new output from rebar
    list-deps
  - Rewrite muc_register_nick and muc_unregister_nick to be DB
    independent
  - WebAdmin: Fix deletion of multiple offline messages
  - Encryption
  - Add support for XEP-0368 in outgoing s2s: SRV records for
    XMPP over TLS
  - Deprecate s2s_use_starttls: required_trusted
  - Don’t attempt to access(2) a certificate file
  - Let ‘domain_certfile’ take higher precedence instead of
    s2s_certfile or c2s_certfile _ Databases
  - mysql.sql: Use multi-column index on username/ID
  - Use forked repo of Riak Erlang client to support OTP20
  - Modules
  - mod_avatar: New module with support for legacy and modern
    clients
  - mod_block_strangers: Introduce option ‘allow_transports’
  - mod_block_strangers: Block messages from strangers before
    mod_mam/mod_offline processing
  - mod_http_upload: Don’t ignore ‘custom_headers’
  - mod_muc: Improve presence-error and unavailable of
    multi-session occupants
  - mod_multicast: Fix start and reading of configured limits
  - mod_mam: Simplify check for anon MUC JID filtering
  - mod_mam: Refuse filtering anon MUC queries by JID
  - mod_privacy: Explicitly match against
  - mod_register: Introduce ‘redirect_url’ option
  - mod_stream_mgmt: Delete ‘c2s_init’ hook
  - mod_vcard_xupdate: Also replace vcard-x-update in direct
    presences
  - PubSub
  - Fix get_items/get_item calls
  - Add correct order when requesting all items
  - Implement ‘6.5.7 Requesting the Most Recent Items’
  - Fix RSM support on SQL
  - Add RSM support on mnesia
  - Fix node_options: default options only apply on first plugin
  - Broadcast updated node configuration
  - Enforce controls on publish and delete items
  - Miscelanea
  - Preserve correct order of deserialized XML elements
  - Suppress push notifications for online clients
  - Extract strings and prepare translation files works again
- changes from 17.08
  https://blog.process-one.net/ejabberd-17-08/
  - Core
  - Erlang/OTP 17.5 or higher is required, and 20 is now
    supported
  - Make ejabberd_cluster modular
  - Replace gen_fsm with p1_fsm to avoid warnings in OTP20+
  - Fix clustering table reg_users_counter
  - ext_mod: Update spec from custom and allow modules
    dependencies
  - extauth.py: Fix to support : in passwords
  - Set high water mark in lager for all backends
  - Fix old route record in mnesia’s route table haven’t been
    remove when restarting in some cases
  - ejabberd_cluster*.erl: Add copyright and fix description
  - Add support of rfc6120 section 4.9.3.16 on node shutdown
  - Configuration
  - ejabberd_c2s: Fix priority of ‘certfile’ option
  - Introduce ‘hosts’ modules option
  - Fix ERLANG_OPTS, INET_DIST_INTERFACE and FIREWALL_WINDOW
    option
  - Remove unused ‘managers’ option, related to the deferred
    XEP-0321
  - Commands
  - Fix errors when running ejabberdctl as root
  - Fix set_presence command to work in recent ejabberd
  - Rename stop_all_connections to stop_s2s_connections for
    consistency
  - Change policy of user_resources command, from user to admin
  - Remove old command calling interface
  - Describe more command arguments and results
  - Modules
  - mod_http_api: Use hide_sensitive_log_data option when
    registering users
  - mod_http_fileserver: Request basic auth dialog from browser
  - mod_muc: Fix nick bug with MUC on riak
  - mod_muc: new hooks
  - mod_push: Support XEP-0357: Push Notifications
  - mod_push_keepalive: New module
  - PubSub/PEP
  - Keep disco#info on PEP compatible with XEP-0060
  - Preliminary export PubSub data from Mnesia tables to SQL file
  - Fix PubSub send last published items
  - Fix PEP node removal
  - Fix PEP node identity
  - Fix disco#items on PEP service
  - Fix getting cached last item
  - Add import of PEP from prosody
  - Documentation
  - Improved API documentation
  - see https://docs.ejabberd.im/developer/ejabberd-api/admin-api/
- move contrib to a separate package
* Fri Jul 14 2017 mrueckert@suse.de
- bump requires of fast_tls to 1.0.14 to get the tls options fix
  new entry in ejabberd-bump-deps.patch
* Wed Jul 12 2017 mrueckert@suse.de
- backport
  https://github.com/processone/ejabberd/commit/f6bdc6fdb.patch
* Tue Jul 11 2017 mrueckert@suse.de
- update to 17.07
  ejabberd 17.07 includes an important security fix. Except this
  fix, the release is completely equivalent to 17.06. If you run
  any version from 17.03 to 17.06, it’s possible to consume all
  available ports regardless of ERL_MAX_PORTS. You should upgrade
  to 17.07 as soon as possible if you are running a public server.
  Please, note that the security of users, data, conversation, etc.
  is not at stake. Data / privacy is safe.
  For all changes see https://blog.process-one.net/ejabberd-17-07/
- changes from 17.06
  ejabberd 17.06 includes a lot of improvements over the previous
  17.04 release. To name the most important ones: new caching
  system, Riak support for several modules and introduction of
  Certificate Manager.
  Certificate Manager is a feature that has been requested by many
  organisations, allowing administrators to manage their
  certificate more easily.  From now, starting ejabberd with an
  invalid certificate will dump a clear entry in ejabberd log file,
  explaining what’s wrong. Upcoming ACME support will further
  refine these improvements we’ve worked on early this year to give
  our users a great experience with certificate management.
  The new cache system is also a new component that allows fine
  tuning of ejabberd performance for either small systems or large
  scale servers. To use data cache for a supported module, you need
  to set the module option use_cache.  You also have the
  possibility to define a maximum number of cache entries and/or
  maximum life time of cached data, so you keep control on your
  memory use.
  For all changes see https://blog.process-one.net/ejabberd-17-06/
- changes from 17.04
  Less than a month after previous release, ejabberd 17.04 is out
  with bug-fixes and new features: Redis and SQL backends can now
  be used to store some RAM tables, the same way Mnesia is doing.
  This release fixes few regressions from previous refactor. If you
  have troubles using PEP or using external modules with ejabberd
  17.03, upgrade to 17.04 should fix everything.
  Refactor efforts are still in progress. If you’re a developer,
  consider ‘jlib’ module as obsolete and do call common helpers
  (like type convertors) from the new ‘misc’ module instead.
  For all changes see https://blog.process-one.net/ejabberd-17-04/
- changes from 17.03
  New modular code, flexible core backend, dynamic configuration
  reload, spam protection and routing API changes.
  These are the most interesting improvements coming in 17.03.
  As usual, we also included several other improvements and many
  bug-fixes. In summary, almost 3K new lines of code and other 10K
  changed lines.
  For all changes see https://blog.process-one.net/ejabberd-17-03/
- changes from 17.01
  We’re pleased to announce the first version of ejabberd for 2017.
  This new ejabberd 17.01 follows closely the previous release. It
  includes mostly bug fixes over all the previous refactors.
  Ejabberd 17.01 is a rock-solid stable base for upcoming
  improvements. It will give you the best experience you ever had
  with ejabberd.  If you ever wanted to upgrade your old ejabberd
  2.1.13 or need a stable base for your server running the next
  couple of months, 17.01 is your best opportunity to get this done
  now!
  For all changes see https://blog.process-one.net/ejabberd-17-01/
- changes from 16.12
  2016 was year of several major code refactors and improvements
  for ejabberd. From Elixir support, to test suite and code clean
    up and modernization.
  After ejabberd 16.09 which brings a lot of improvements, ejabberd
  16.12 includes a big refactor we have been preparing for long
  time, and a couple of new features that pursue the central effort
  on API, commands and web integration started early this year.
  ejabberd 16.12 includes: a new API permissions framework for
  commands, a new more reliable BOSH module, major code refactor,
  more integration and unit tests, improved support for Erlang/OTP
  R19, compatibility with rebar3 build system, many fixes and
  optimizations, and Docker containers.
  For all changes see https://blog.process-one.net/ejabberd-16-12/
- update contrib 2a95a53285d743696dd5e1bdd4b3497cd9a2d7da
  - Fix typos in previous commit (#218)
  - Update to work with ejabberd 17.06
  - Fix starting mod_cron in recent ejabberd 17.04 (#214)
  - Update to the updated ejabberd_auth API
  - Update mod_logxml to work with ejabberd 17 (#209)
  - Merge pull request #206 from zeroows/patch-1
  - Changed from Txt to Md
  - Update mod_logsession to work with ejabberd 17.01 (#201)
  - Explain that mod_pottymouth may require an alternative library
    (#198)
  - Fix mod_statsdx to start correctly with ejabberd 17.03
  - Update to work with 17.03+
  - Update mod_rest to 16.12, but can send only messages, not iq or
    presence (#196)
  - Make mod_post_log working with ejabberd 16.12+
  - Merge pull request #181 from madglory/master
  - dynamic character replacement / muc message filter fixes
  - Update IP format in mod_rest example configuration file (#190)
  - move list_to_bin on filterMessageText for clarity
  - add depends/2 to mod_pottymouth... seems to be required by
    gen_mod now
  - remove README.md
  - filter all body elemements in message
  - initial multi-body parse
  - fix lookup/substitution of unicode (example: chinese)
    characters
  - pull message body attibs to look for lang
  - re-add repo README.md
  - Merge branch 'master' of github.com:processone/ejabberd-contrib
  - update README.txt with charmap description. remove README.md.
  - add pattern to match group chat messages for filtering
  - code cleanup. add optional normalize_leet to do dynamic
    substitution of one-to-one mappings (reduce blacklist size).
- disable contrib modules until we know how to fix them:
  - mod_cron
  - mod_muc_log_http
- added ejabberd-bump-deps.patch to bump some version requirements
  in ejabberd
- refreshed patches to apply cleanly again
  ejabberd-16.01_document_optional.patch
  ejabberd-16.06_dont_run_as_root.patch
- updated ejabberd-fix_make_install_when_using_system_deps.patch
  and also skip "all" section during make install to make it work
  with new build system
- moved all buildrequires to package names ending in -devel
- reordered %%requires_eq statements to be together with their
  respective buildrequires
* Fri Sep 23 2016 mrueckert@suse.de
- update to 16.09
  https://blog.process-one.net/ejabberd-16-09/
  We are happy to introduce our new ejabberd release, ejabberd
  16.09. As usual it includes many bug fixes and improvements. But
  most of all, it includes excellent student work done for Google
  Summer of Code program.
  More specifically, this release adds the following major
  features:
  - Support for Elixir configuration file. It means it is possible
    to configure ejabberd using an Elixir script file instead of
    ejabberd YAML format.
  - Support XEP-0355 – Namespace Delegation This allows to use an
    external entity to manage some of the server features. This XEP
    is working with Privileged Entity (XEP-0356).
  - Support XEP-0356 – Privileged Entity This allows a component or
    any entity to have a “privileged” status. As a result, it can
    manage an entity roster on its behalf, send or receive stanzas
    in the name of the server. The main goal of XEP-0356 is to
    create an external, server agnostic, PEP service.
  - New XMPP Extension support
  - Support for XEP-0355 – Namespace Delegation
  - Support for XEP-0356 – Privileged Entity
  - Elixir support
  - Support for Elixir-based configuration files
  - MUC/Sub
  - Add a new request to list MUC room subscribers
  - Link MUC subscription to bare JID
  - New commands unsubscribe_room and unsubscribe_room for MUC
    subscriptions management through API
  - Fix nick-to-jid mapping for MUC subscribers
  - Fix subscribed rooms list retrieval
  - Fix message routing from subscribers
  - Do not update muc_online_users table on MUC/Sub operations
  - MUC
  - Support multiple JIDs in room invitations
  - Create room on configuration request as per XEP-0045, 10.1.3
  - PubSub
  - Add SQL support for microblogging node plugin
  - Fix publish with subscriber publish model and SQL backend
  - node_mb: Call node_pep instead of node_hometree
  - Stream Management
  - New Stream Management option: ack_timeout
  - Fix Stream Management feature for the websocket connections
  - Cancel timer when waiting for resumption
  - MAM and Offline
  - Don’t store messages of type “headline”
  - Simplify “assume_mam_usage” option
  - Honor hint for any non-“error” message
  - Store announcements for offline users
  - Database
  - Session backend: fix clean Redis table
  - mod_shared_roster: Support SQL backend
  - ejabberdctcl admin tool
  - ejabberdctl: do not force access rules check on register
    command
  - ejabberdctl: do not force command line to pass a credential
  - New commands unsubscribe_room and unsubscribe_room for MUC
    subscriptions management
  - New command create_room_with_opts to create room with custom
    config
  - ejabberd API
  - New commands unsubscribe_room and unsubscribe_room for MUC
    subscriptions management
  - New command create_room_with_opts to create room with custom
    config
  - Add X-Admin and basic auth header to CORS allowed headers in
    http_api
  - Properly process OPTIONS header in http_api for all paths
  - Expand parsing of JSON input to be able to handle
    update_roster command
  - Provide proper args_desc in oauth_issue_token command
  - Developer features: ejabberd Hooks
  - Add hooks c2s_session_pending, c2s_session_resumed,
    store_offline_message, store_mam_message
  - Add CSI user’s JID argument to csi_filter_stanza and
    csi_flush_queue hooks
  - Add functions to get/set some c2s #state elements from
    external modules
  - mod_client_state: Let other modules filter stanzas
  - rework c2s API to simplify push modules integration
- drop upstream patches:
  a0c8012c.patch
  efc74409.patch
- refresh patches to apply cleanly again:
  ejabberd-16.01_document_optional.patch
  ejabberd-fix_make_install_when_using_system_deps.patch
- drop p1_xmlrpc dependency
- update contrib
  - Show more prominently notice that some modules don't work with
    new ejabberd
  - src/mod_rest.erl:27: Warning: undefined callback function
    depends/2 (behaviour 'gen_mod')
  - Replace now() which is deprecated (processone/ejabberd#1264)
* Tue Aug 16 2016 mrueckert@suse.de
- fix ejabberdctl register:
  a0c8012c.patch
  efc74409.patch
  patches can be removed with next version update
* Tue Aug 16 2016 mrueckert@suse.de
- update to 16.08
  https://blog.process-one.net/ejabberd-16-08/
  This new release is the culmination of several months of work to
  improve your experience using ejabberd. It contains as usual a
  lot of small bug fixes and some enhancements. However, this
  version contains some new major features:
  - MUC/Sub
  - Major clean-up and improvement on OAuth ReST API
  - Database backend for OAuth tokens
  - Better support of Elixir modules
  - Full compatibility with Erlang 19
  - Modules loading in a dependent order
  - MUC
  - New MUC/Sub support
  - Add ‘allow_subscription’ room configuration option for
    MUC/Sub
  - OAuth and ReST API
  - Add OAUTH SQL backend
  - New special scope: ejabberd:admin and ejabberd:user, to more
    easily grant group of privileges
  - Add DB backend support for ejabberd_oauth
  - Added ejabberdctl commands to manage OAuth tokens:
    oauth_issue_token, oauth_list_tokens, oauth_list_scopes,
    oauth_revoke_token
  - Simplified OAuth form: username and password merged into JID
    field
  - User configurable validity duration for tokens on OAuth token
    generation form
  - Add support for sending back missing scope error to API ReST
    command calls
  - Oauth: several minor fixes
  - Support oauth password grant type, to generate token
    programmatically
  - Elixir support
  - Update supported Elixir version to 1.2 and 1.3.
  - Support installation of Elixir contributions with external
    module
  - command line tool.
  - PubSub
  - Fix use of like parameter in sql pubsub’s requests
  - Fix node configuration change with sql backends
  - Fix send_last_items duplication with multi-plugin setup
  - MAM
  - Always limit result set page size
  - Use hooks instead of direct calls
  - API
  - Add support for checking access rules conformance for
    commands
  - Add support for rich error reporting for API
  - Add support for sending back missing scope error to API ReST
    command calls
  - Fix handling of complex values as arguments in http_api
    Improve error handling
  - Other improvements
  - External Component Connection Hooks
  - Fix compilation issues on R19
  - Support for OpenSSL 1.1
  - Make access rules in ejabberd_web_admin configurable
  - Make modules loading in a dependent order (#1191)
  - Make s2s stats commands more robust
  - Preserve PID for offline sessions
  - Several quoting fixes for PostgreSQL
  - Switch supervised workers from temporary to transient
- update contrib to 41371cf
  - mod_rest allow ipranges
  - added mod_grafite. send statistics to graphite/statsd
  - Fix ejabberd_auth_http module_check
  - mod_pottymouth: Arbitraty blacklist size
  - mod_pottymouth: update bloom_gen_server to support arbitraty
    list sizes. tested up to 87M terms. update README.
  - mod_pottymouth: bring back bloom_gen_server stop() to avoid
    error messages
  - adding mod_pottymouth
- updated ejabberd-fix_make_install_when_using_system_deps.patch
  to apply cleanly again
* Tue Jul  5 2016 mrueckert@suse.de
- added ejabberd-16.06_dont_run_as_root.patch: (boo# 987588)
  As we dont want to have a login shell for the ejabberd user, the
  call to su fails.  Switching to sudo internally, requires some
  more work as the quoting needs to be fixed in all the places.
  For now only run as user ejabberd. That way we only call bash and
  bypass the broken code.
  This was especially annoying as the execs didnt have any error
  handling and no output for the user.
- merge our service file with the template from upstream.
  all the commandline options specificed were just reflecting
  defaults. if an user wants to override those, it should be done
  in /etc/ejabberd/ejabberdctl.cfg and not on the commandline.
- also adds support for the reload target
* Wed Jun 29 2016 mrueckert@suse.de
- update to 16.06
  Important: Read about the ACL changes on
  https://blog.process-one.net/ejabberd-16-06/
  - Config
  - New ACL infrastructure
  - Add shorter version of some common access rules definitions
  - Allow @ inside acl rules user, user_glob or user_regexp to
    pass both user and server
  - in single string
  - Add acl rule access_rules_validator and
    shaper_rules_validator for use in mod_opt_type and opt_type
    callback functions.
  - Allow using shapers defined by name like in s2s_shaper: fast
  - Allow mod_opt_type and opt_type to transform values passed to
    it, and support
  - better error reporting
  - Do not call transform_terms multiple times in configuration
    processing when merging them
  - Don’t halt program when include_config_file is missing/can’t
    be read
  - Allow again multiple fqdn values in configuration
  - Commands
  - Allow passing username and ip to ejabberd_commands, and use
    it in mod_http_api
  - Fix path to epmd in ejabberdctl
  - push_roster: must convert read strings to binaries
  - set_presence: Fix command API
  - Fix for modules_update_specs command
  - Add ejabberdctl commands to manage oauth tokens.
  - Core
  - Bounce messages sent to server JID
  - Fix C2S session leak in rare cases
  - Fix handling of queued stanzas on session timeout
  - Give more time to stop and kill epmd
  - When stopping ejabberd, stop modules after broadcasting c2s
    shutdown
  - XEP-0198: Use different error message for bounces
  - XEP-0198: Add ‘h’ attribute to element
  - XEP-0198: Also count stanzas when socket is closed
  - Databases
  - Fix pgsql compatibility on delete_old_messages command
  - Handle Redis connection in a separate module
  - Report in SQL when scram is enabled but the stored password
    isn’t
  - Update SQL escaping
  - Use MEDIUMTEXT type for muc_room.opts in MySQL schema
  - MAM
  - Send unique stanza id and archived tag also in the message
    carbons
  - Fix “assume_mam_usage: if_enabled”
  - Fix typo in mod_mam:select()
  - Updated support of XEP-0313 from version 0.4 to 0.5.1
  - Mnesia: Avoid cleanup on bag when disc_only, switch in memory
  - Mnesia: Don’t exceed table size limit
  - Mnesia: Use transactions when writing
  - Client State Indication
  - Fix handling of chat states
  - Simplify check for carbon-copied chat states
  - Simplify handling of PEP stanzas
  - Pass chat states of other resources
  - Unwrap carbon copies when checking for chat states
  - Add queue_pep option
  - Queue chat state notifications
  - Move CSI queue handling code from ejabberd_c2s
  - When stopping, delete only the configured hooks
  - Other modules
  - ext_mod: Set HTTP/1.0 so Github accepts the request
  - gen_mod: Compile early to remove undefined behaviour warning
  - mod_http_upload: Let client retry HTTP upload on file size
    mismatch
  - mod_last: Produce mod_last entry on account creation
  - mod_muc_room: Notify on affiliation changes
  - mod_register: Check password with jid:resourceprep when
    registering account
  - mod_roster: respect roster item changes introduced with
    roster_process_item hooks upon pushing
  - PubSub: Fix PubSub RSM on get_items
  - PubSub: Add support for PubSub publishing options
  - PEP: Fix sender in case of explicit pep subscriptions
  - ejabberd_xmlrpc: Report error when conversion of argument
    type fails
- refreshed patches to apply cleanly again
  - ejabberd-16.01_document_optional.patch
  - ejabberd-fix_make_install_when_using_system_deps.patch
* Sat May 21 2016 mrueckert@suse.de
- update to 16.04
  - API Commands
  - Add API versionning
  - Changed error handling, based on exception
  - ejabberd Command bugfixes
  - Accept commands: add_commands syntax (along commands: –
    add_commands)
  - Fix mod_muc_admin:get_room_options and set_room_affiliation
  - mod_http_api: support ‘open’ ejabberd commands
  - Databases
  - Split modules DB specific code into separate modules
  - Rename “odbc” to “sql” everywhere
  - Rename “internal” auth to “mnesia”
  - Improve detection of databases supported by modules
  - Switch to varchar(64) in mysql user.server/salt as text can’t
    have default values
  - ‘serverkey’ and ‘salt’ should have empty string as default
  - XMPP
  - Drop headline messages sent to offline resources
  - Don’t omit bounces for messages of type “result”
  - Match namespace when checking for chat states
  - Fix check for standalone chat state notifications
  - Disable TLS compression for s2s by default
  - Make sure that ejabberd_sm sid are unique
  - Send stream trailer at the very end of the processing
  - Generate shorted jid for anonymous connections
  - Fix anonymous SASL auth
  - ejabberdctl
  - Add option to migration script to delete data from a table
    after they have been successfully moved to SQL database:
    ejabberdctl delete_mnesia example.org
  - Remove useless variable and quote EPMD and SPOOL_DIR
  - Fix node ping command
  - Use UUID for ctl node name
  - Remove –auth in ejabberd_ctl.erl as it’s useless, still
    useful for mod_rest
  - Force ERL_PATH for Elixir console
  - Pubsub
  - ix use of pubsub node plugin when configured with
    default_node_config
  - et default value for pubsub#itemreply option
  - dd subscribe/unsubscribe hooks
  - Internal
  - Add mod_mam header file
  - Replace ?ERR_* macros with ?ERRT_*
  - change mod_ping Timers using maps instead of dict
  - Dependencies
  - Update p1_utils to 1.0.4: Adds
    p1_time_compat:unique_timestamp()
  - Uptate fast_tls to 1.0.3: Prevent buffer overflows and
    allocation failures
  - Uptate stringprep to 1.0.3: Fix compilation on Windows and
    error message
  - Uptate stun to 1.0.3: Use fast_tls 1.0.3
  - Uptate esip to 1.0.4: Use fast_tls 1.0.3
- update contrib to d7ce81c
  - Fix problem registering users with ejabberd_auth_http
    https://www.ejabberd.im/forum/25450/issue-registration-users-over-bosh#new
  - Add AuthzId argument to ejabberd_auth_http:check_password
    (#164)
  - mod_message_log: Add mod_opt_type/1 callback
  - Ensure --auth is provided, so ejabberd_ctl checks
    AccessCommands (#159)
  - Update mod_rest example configuration to new format (#161)
- update ejabberd-fix_make_install_when_using_system_deps.patch:
  skip moka build dependency. only needed for the testsuite.
  samerlib, a moka dependency, doesnt build atm.
- replace erlang-rebar-obs with erlang-rebar:
  export REBAR_DEPS_PREFER_LIBS to make sure it prefers installed
  deps
- adapt file list to follow the restructuring in the database
  modules
* Fri Apr  8 2016 mrueckert@suse.de
- update to 16.03
  ejabberd development keeps on its steady pace and we are
  energized by the growing momentum. Thank you all for your
  feedback and contributions for that release.
  This new ejabberd release contains many many bugfixes, internal
  improvements, but also, as usual, some new features.
  We are very excited by the experimental support for Mediated
  Information eXchange (MIX) we have added in ejabberd 16.03. This
  is the future of Multi User Chat for XMPP. While still rough, you
  can already give it a try and help improve the specification. You
  can learn more from our previous blog post: Experimental MIX
  Support for Group Conversations added to ejabberd
  We have also started improvements of various third-party backends
  such a Microsoft SQL Server and LDAP. This is the beginning of a
  process to improve support of those backend, so please, bare with
  us and keep us posted on your results.
  - Protocols
  - mod_mix: Experimental support for MIX (XEP-0369)
  - mod_http_upload: Add support for XEP-0363 v0.2
  - Core
  - Use SASL PLAIN authzid as client identity if auth module
    permits it
  - Make auto generated resources shorter
  - Start ezlib only if required, as it’s optional
  - Make it possible to get virtual host of a registered route
  - LDAP improvements
  - Fix issue getting shared roster
  - Do not call to deprected/undefined functions from
    mod_shared_roster_ldap
  - Proper naming for LDAP test function for shared roster
  - SQL databases support
  - New parse transform for SQL queries, use prepare/execute
    calls with Postgres
  - Support for run-time SQL queries selection depending on DBMS
    version
  - In SQL files create Users table with SCRAM support by default
  - Do not auto append IP suffix to usernames
  - Fix some LIMIT related problems with MSSQL
  - Update Microsoft SQL Server schema
  - Riak
  - Add support for Riak authentication
  - Fix is_connected/0 function
  - Keep alive Riak connections by default
  - API and Commands
  - Add support for ReST admin commands that are only restricted
    by source IP. This is key for easy integration with other
    backend using ReST API.
  - Fix add_commands and remove_commands options
  - Pass noauth when auth isn’t provided
  - Improve ban_account command to work with other DBs than
    Mnesia
  - Escape quoting node name for ejabberdctl ping
  - Bare JID in ‘from’ of Roster Push (RFC 6121 section 2.1.6) in
    mod_admin_extra
  - Fix result type of “connected_users_info” command
  - New command delete_mnesia deletes all tables that can be
    exported. This is useful after you have migrated to another
    backend, like SQL.
  - PubSub
  - Unregister route at the very end
  - Define PubSub node configuration per route/host explicitly
  - Fix config fetch and pubsub disco after host/serverhost
    cleanup
  - Admin and build chain
  - Update OTP release to use R17.5 and drop release 17.1
  - Compile ejabberd_config early to stop undefined behaviour
    warnings
  - Fix start via systemd
  - Fixed type specifications for ‘rebar doc’
  - Specify lacking nodename in ejabberdctl
  - Dependencies
  - Update p1_pgsql to 1.1.0: This add support for prepared
    statements.
  - Uptate fast_yaml to 1.0.3: This improves the error reporting
    on syntax errors in Yaml configuration file.
  - Use the v0.2 release of luerl instead of a commit.
  - Test framework
  - Add Coveralls support
  - Add ability to run the ejabberd test suite in a modular way.
    You can now run the test suite, even if you only have a a
    single backend locally.
  - Other
  - mod_mam: Don’t store watchdog notifications in MAM archives
  - mod_multicast: Fix Addresses element which lacked others
    local destinations
  - mod_offline: Mark get_queue_length obsolete, and use
    count_offline_messages
  - Update Gallician translation
- update contrib to
  - Fix mod_cron still looking for xml.hrl (#157)
  - Fix in mod_profile old call to gen_mod:get_opt (#160)
  - Fix unicode character handling in command arguments
    Many thanks to Krzysztof Grochocki for finding this fix.
    This fixes issue #153.
* Tue Mar  8 2016 mrueckert@suse.de
- update contrib to 32fd4c4
  - 16.02 fixes for many modules
  - mod_mam_mnesia is dead.
    For the how to migrate to the new mod_mam.  please see
    /usr/share/doc/packages/ejabberd/mod_mam_mnesia/README.md
    The import script can be found as /usr/sbin/import-mam-archives
- add mod_cron.compile.patch to fix building mod_cron with 16.02
* Sat Mar  5 2016 mrueckert@suse.de
- update to 16.02
  To celebrate leap day, we are happy to release ejabberd 16.02,
  which mark huge leap for ejabberd both in terms of features and
  improvements.
  In terms of features, we see in this release the culmination of
  our work in several areas:
  – Support for flexible offline retrieval, aka XEP-0013. This is a
    big win for mobile developers.
  – Improvements on archiving, with Message Archive Management
    (MAM) now supporting version 0.4.1 of the specifications.
  – Full Elixir compliant packaging with the ability to deploy
    ejabberd as an Hex.pm dependency from your own application.
    See ejabberd on hex.pm.
  – Performance improvement with faster and more memory efficient
    XML parsing and TLS encryption. You can also refer to our
    previous blog post: ejabberd Massive Scalability:
    1 Node — 2+ Million Concurrent Users
  – Better stream compression with the ability to enable stream
    compression after SASL.
  – Easier adoption of ejabberd with a new migration script from
    Prosody XMPP servers.
  As usual, this version is the product of a great community team
  work, with special kudos to Holger, Alexey, Evgeny, Pawel,
  Christophe, Badlop, Mickaël for their large contributions in this
  release.
  That community effort is what makes ejabberd is such a popular
  project, with 2260+ stars on Github, availability in most Linux
  distributions and showing amazing number of downloads ! Thank you
  all !
  Here is the full list of changes:
  - New XMPP Extensions support
  - New Flexible Offline Message Retrieval (XEP-0013) support
  - Admin
  - New migration script from Prosody to ejabberd
  - Fix --disable-debug compilation flag
  - don’t escape ERL_OPTIONS
  - Two new global timeouts configurable: c2s_hibernate,
    receiver_hibernate
  - Make it possible to define sm_db_type per virtual host
  - configuration checker: Describe option type in code for
    domain_balancing option
  - Log failed SQL requests
  - Include mod_muc.hrl and fix records
  - mod_http_upload: Expand docroot before using it, also expand
    @HOST@
  - Commands
  - New import_prosody command
  - Start documenting arguments in mod_admin_extra commands
  - We added a way to get all ejabberd_commands, not only those
    that was registered
  - Allow to pass \n in argument to ejabberdctl
  - Add error handling to send_stanza command
  - Fix format_result so get_room_options command works again
    after commit reference aa5caa3
  - Dependencies
  - lager is the default (and only) logging module and we removed
    p1_logger
  - Handle spaces in vsn attribute of app file when installing
    deps
  - Renamed dependencies and modules for consistency but also to
    reflect huge performance gains:
  - p1_iconv -> iconv
  - p1_stringprep -> stringprep
  - p1_stun -> stun
  - p1_tls -> fast_tls
  - p1_yaml -> fast_yaml
  - p1_zlib -> ezlib
  - Message Archive Management
  - Advertise MUC MAM v0.4.1 in room JID’s disco#info
  - Add “delete_old_mam_messages” admin command
  - Add ‘from’ attribute to tag
  - Add “request_activates_archiving” option
  - Respond to form requests
  - Support XEP-0313 v0.2 MUC archive queries
  - Check whether MUC message is desired
  - Reject -based paging
  - Limit result set page size
  - Sort messages returned by Mnesia
  - Strip existing JID tags from MUC messages
  - Expose MUC occupant JID in more cases
  - Don’t let outcasts access MUC archive
  - Send new preferences when they are set
  - Stream management (XEP-0198): Let MAM take care of pending
    messages
  - GroupChat
  - Send presence with code 170 in initial presence from MUC
  - Add most status codes only to initial MUC presence
  - mod_muc_room: Don’t expose JIDs in anonymous rooms
  - mod_muc_room: Let members see admin/owner JIDs
  - PubSub
  - Fix presence-based delivery
  - Make caps warning less confusing
  - Fix host/serverhost usage
  - Add support of pubsub#itemreply=publisher
  - Other
  - Accept stream compression request after SASL
  - Make C2S session establishment optional to better conform to
    XMPP specifications and still be friendly with older clients.
  - MUC: new regexp_room_id option to limit possible room names.
  - ODBC: Set utf8mb4 charset on MySQL connection to support
    emoji storage as default.
  - LDAP: Improve LDAP shared roster support.
  - mod_register_web: Allow setting host when deleting account or
    changing password.
  - Rename timestamp_to_iso functions in jlib.
  - Stream management (XEP-0198): Fix session timeout corner
    case.
  - Several improvements in Elixir support.
  - Updated many translations.
  - Improve web admin stylesheet to fix rendering issues in some
    browsers.
- refresh ejabberd-fix_make_install_when_using_system_deps.patch
* Tue Feb 23 2016 mrueckert@suse.de
- added ejabberd-16.01_document_optional.patch:
  document those new optional packages in the example config
* Tue Feb 23 2016 mrueckert@suse.de
- make imagemagick and ghostscript recommends on distro that
  support it. it is only used for captchas.
* Tue Jan 19 2016 mrueckert@suse.de
- run make xref to find if one of our dependencies is too old and
  ejabberd uses symbols we are missing.
* Tue Jan 19 2016 mrueckert@suse.de
- update ejabberd-fix_make_install_when_using_system_deps.patch:
  allow newer meck
- replace all paths to libdir/ejabberd with ejabberd_dir macro as
  it is now versioned.
* Fri Jan 15 2016 mrueckert@suse.de
- update to 16.01
  This release contains security fix for possible server spoofing
  with brute force attack on the random number generation. Even if
  the issue is difficult to exploit, it is recommended to upgrade
  your server if you’re using server-to-server (s2s) connections.
  It also includes: – better groupchat archiving support with MAM –
  improved PubSub performances and control – more shaper
  capabilities for listeners – performance optimisation and lower
  memory consumption of the core XML processing modules – faster
  core routines
  Full changes:
  - Security
  - Improve Dialback Key Generation and Validation support
    (XEP-0185)
  - More generally, improve random number generator to avoid
    timing / guessing attacks on any random value.
  - Database
  - Use BLOB instead of TEXT on mysql in stanza storage
  - Use UTF8MB4 character set in MySQL tables
  - Make Riak working on Erlang R18
  - MAM
  - Use stanza-id tags for deduplication
  - Advertise MAM in disco info for account/room JID
  - Improve MUC support
  - Don’t store resent messages
  - Do not forget to include xmlns in mam prefs response (#859)
  - Honor Message Processing Hints (XEP-0334)
  - MUC
  - Add support for muc#roomconfig_presencebroadcast option
  - Only filter rooms in Service Disco when more than 100
    (EJAB-343)
  - List in Service Disco non-empty rooms and provide Node for
    empty (EJAB-343)
  - When user joins logged room, he must be warned (EJAB-726)
  - Pubsub
  - Fix pubsub virtual nodetree plugin
  - Use correct notification_type for last items (#827)
  - PubSub plugin for online users only
  - Disable use of multi-subscribe and subscription-option on
    standard plugins
  - Limit number of subscriptions per node and allow custom
    default node configuration
  - Don’t force max_items_node to MAXITEMS if not defined
  - Don’t read pubsub options when plugin does not use them
  - Elixir
  - Upgrade Elixir to v1.1.0
  - Admin
  - Add plugin for passing extra erl_opts flags to deps, and use
    it for hipe
  - Add –enable-latest-deps to configure
  - Remove “–enable-nif” flag
  - New send_stanza command
  - ejabberdctl: new –no-timout flag
  - ejabberdctl: Don’t let “reopen_log” rotate files (EJAB-1243)
  - ejabberdctl: Improve escaping of arguments passed to
    ejabberdctl
  - OpenSSL minimum required version: raised from 0.9.8 to 1.0.0
  - Config
  - New option accept_interval in ejabberd_listener
  - Webadmin console visual refresh (EJAB-1142)
  - If mod_register access_from is ‘none’, then don’t advertise
    IBR (#857)
  - Fix handling of some options in old style configs
  - Fix parsing option trusted_proxies
  - Fix ipv6 configuration processing (#803)
  - ejabberd_service: simplify configuration: no need for
    ‘hosts’, just provide ‘password’
  - Cleanup and optimisations
  - Faster string_to_jid/1 implementation
  - Move JID related functions from jlib.erl to jid.erl (#847)
  - Remove usage of erlang’s now()
  - Update dependency name from p1_cache_tab to cache_tab
  - Use crypto:rand_uniform instead of random:uniform
  - Fix randoms.erl on R17 that don’t have random:seed(integer())
  - Faster and more memory efficient XML parsing.
  - Faster stringprep library.
  - Other changes
  - ejabberd_http: Cope with large POST/PUT requests
  - ejabberd_http: Log debug message on receive errors
  - mod_offline: Discard chat states notifications
  - mod_offline: Honor store hint
  - mod_http_upload: various fixes
  - XEP-0198: Fix stanza counting corner case issue
  - Adding WEBIRC, custom realname & ident, ISO-8859-15 (thanks
    to iwalkalone69)(#877)
  - Update hebrew translation
- update contrib to d73b648
  mod_http_upload: Use application/octet-stream instead of
    text/html for security reasons
  mod_http_upload: Add note regarding "get_url"
  mod_http_upload: Use full PUT URL for process name
  mod_http_upload: Rename variable for clarity
  mod_http_upload: Fix logging of file size mismatch
  mod_http_upload: Return error atoms, not strings
  mod_http_upload: Log message if URL looks wrong
  mod_http_upload_quota: Don't track all users
  mod_http_upload: Make case indentation consistent
  mod_http_upload: Apply cosmetic changes
  mod_http_upload: Don't flatten command strings
  mod_http_upload: Don't let identify/1 return error
  mod_http_upload_quota: Omit info message
  mod_http_upload: Don't complain during shutdown
  mod_http_upload: Use binary strings in most places
  mod_http_upload: Check availability of ImageMagick
  mod_http_upload: Suppress error on non-image files
  mod_http_upload: Fix string()/binary() type issue
  mod_http_upload: Add/fix function specifications
  mod_http_upload: Strip newline from command output
  mod_http_upload: Support thumbnail generation
* Thu Nov 26 2015 mrueckert@suse.de
- remove *cluster from the file list
* Thu Nov 26 2015 mrueckert@suse.de
- update to 15.11
  - Allow longer command execution time
  - Easier cluster setup:
    https://blog.process-one.net/ejabberd-15-11-simpler-cluster-setup/
- update contrib to 195daf9
  documentation update for mod_http_upload
* Thu Nov 26 2015 mrueckert@suse.de
- move mod_mam to the main package where it belongs.
* Fri Oct 30 2015 mrueckert@suse.de
- update to 15.10
  This month’s ejabberd release contains brand new features, performance
  optimisations, bugfixes and many other improvements.
  This release includes a brand new module to help with file
  transfer. In XMPP transferring files between users required users
  to be online at the same time. It all changed with XEP-0363 and
  it is now possible to share file using HTTP protocol while doing
  the signaling over XMPP. Thanks to Holger and Evgeny, we are now
  pleases to include this feature in ejabberd core, with
  mod_http_upload.
  ejabberd now also include a module to export metrics information
  about ejabberd behaviour to Grapherl, a tool that was developed
  during the Google Summer of Code by Vanshdeep Singh. This is only
  the beginning, as we are planning to both increase the number of
  metrics and available backends in upcoming releases. As a start,
  you can now track the traffic (both from clients and between
  servers), the offline messages and the user registration and
  account deletion.
  We improved the overall performance of ejabberd, thanks to
  optimisation in the XML parser.
  We also improved the documentation to help you set up mod_xmlrpc
  with OAuth for those who were already using it prior to 15.09
  release.
  Finally, as usual, we fixed bugs and improved many features
  across the whole server.
  - Core
  - c2s: Let stop/1 close XEP-0198 sessions
  - c2s: Close socket when waiting for resume
  - s2s: Don’t crash on certificates without extensions
  - xml: Optimizations in memory allocator
  - OAuth: Fix cyrsasl_oauth:mech_new call
  - Modules
  - mod_http_upload: New HTTP File Upload module (XEP-0363)
  - mod_http_upload_quota: New module to support user quotas
  - mod_metrics: New simple metrics module for use with grapherl
  - mod_mam: Advertise XEP-0313 v0.4 support in room disco
  - mod_mam: Avoid MAM dups when routing to multiple resources
  - Compilation
  - Make: Pass {C,CPP,LD}FLAGS used in main ./configure to deps
  - Use OTP directory structure for ‘make install’
  - mix.lock should be commited to ensure consistent builds
  - Code cosmetic cleanup
  - Commands
  - et modules_update_specs report failures
  - ix problem with –auth
  - ix unauthenticated calls to commands with policy=user
  - mprove access_commands option backward compatibility
  - Configuration
  - ejabberdctl.cfg: New CONTRIB_MODULES_CONF_DIR
  - Be able to merge old style configs with {listen,…}
  - Fix support for macros
  - mod_ping: New option ping_ack_timeout
- update contrib to 1ee52e2
  - Fix IRCd module to work on modern ejabberd
  - Use homogeneous s2s connections stats (processone/ejabberd#761)
- refreshed ejabberd-fix_make_install_when_using_system_deps.patch
  to apply cleanly again.
- do not build mod_http_upload from contrib anymore, it is included
  in the core.
* Sun Oct  4 2015 mrueckert@suse.de
- update to 15.09
  This month’s ejabberd release contains some major improvements and few fixes
  since the last release two months ago. On top of improvements is support of:
  - OAuth 2.0 delegation framework
  - preliminary OAuth and HTTP based ejabberd API,
  - X-AUTH2 authentication mechanism,
  - and message archiving for Multi-User Chat.
  This is a major milestone for ejabberd, as it makes it a central components
  that can integrates and play well with Web HTTP based clients, components and
  services. You can learn more about our OAuth support from ejabberd OAuth
  documentation. With this support, we are exposing 13 commands from ejabberd
  API over HTTP with OAuth. This is just a start to get feedback and bootstrap
  a community effort to make ejabberd API right. We are expecting to hear from
  you !
  Moreover, Message Archive Management now supports the latest proposal for
  Archiving and Multi-User Chat support, based on recent clarifications we
  proposed in XEP-0313.
  Finally, we are keeping improving our support for Microsoft ecosystem. As
  Microsoft Windows support is back since 15.07, we also restored the MSSQL /
  Azure database server support through ODBC driver. This is a big step for
  users under Windows Server infrastructures.
  Major changes
  - Added OAuth delegation framework
  - Preliminary OAuth and HTTP based ejabberd API
  - X-AUTH2 authentication mechanism,
  - MAM now can store MUC room
  - Note: ejabberd now requires erlang 17.1 or higher
  Core improvements
  - New set_loglevel admin command to ease changing loglevel.
  - Configuration: allow to override main config file options with data from
    included files
  - Improve S2S certificate checks
  - Log TLS errors as [debug] messages only
  - XEP-0198: new option “max_resume_timeout”
  - XEP-0198: Improve handling of non-message stanzas
  - ext_mod: Check external modules configuration on load
  - ext_mod: Don’t override custom configuration on module upgrade
  - Several Elixir fixes
  - Updated most translation languages
  Modules improvements
  - Carbon Copy: Don’t copy messages of type “normal” without body
  - HTTP-Bind: More eye-candy mod_http_bind help page
  - HTTP-Bind: Nameprep host name passed to http-bind before using in
  - HTTP-Bind: Set disable caching headers in http-bind responses
  - HTTP: pass stream management options defined in http listener to http-bind
    and websocket
  - MAM: Add XEP-0359 to archived messages
  - MAM: Add XEP-0313 v0.4 support
  - MUC commands: Changed argument names in two commands
  - MUC commands: Fix and document create_rooms_file and destroy_rooms_file
  - MUC hooks: added muc_filter_presence
  - MUC hooks: renamed muc_filter_packet to muc_filter_message
  - MUC logging: check for hint
  - Multicast: many improvements in the source code
  - SIP: Do not crash SIP authentication on SCRAMed passwords
  Packaging
  - Remove bashisms in join_cluster leave_cluster and postinstall scripts
  - Allow root to run join_cluster and leave_cluster
  - Allow building an ejabberd release with mix and elixir release manager
  - Allow installing as root
  - Rename idna to ejabberd_idna
  - Improve ‘make install’ to remove useless failure cases
- update contrib to 0451576
  - Add policy to commands definitions (#123)
  - Define accepted module options
  - mod_http_upload: Update function specification
    The handle_call/3 function now responds to some requests.
  - mod_http_upload: Update required ejabberd version
    The mod_http_upload module calls ejabberd_config:may_hide_data/1
    which was introduced in ejabberd 15.06.
  - mod_http_upload: Also start 'asn1' application
    If an HTTPS service_url is specified, start the 'asn1'
    application as well, as 'public_key' depends on it.
    Once mod_http_upload requires Erlang/OTP R16B02 or newer, we
    can use the following calls instead:
    {ok, _} = application:ensure_all_started(inets),
    {ok, _} = application:ensure_all_started(ssl).
  - mod_http_upload: Correct error message
  - Add mod_opt_type function (#121)
  - In yml config, use # as comment instead of ; (#121)
  - Fix comment character encoding (thanks to Evgeniy)(#121)
- refreshed ejabberd-fix_make_install_when_using_system_deps.patch
* Mon Sep 14 2015 mrueckert@suse.de
- update contrib to 6ca6f02
  - mod_http_upload: Handle HEAD and OPTIONS requests
  - mod_http_upload: Suggest cron jobs in README.txt
    Admins might want to set up cron jobs to remove old uploaded
    files.
  - mod_http_upload: Mention Django app in README.txt
    Mention the Django app written by Mathias Ertl as an example of
    a service that can be used together with mod_http_upload.
  - mod_http_upload: Set mode bits of all directories
    When the "dir_mode" option is specified and the file
    root/a/b/file.png is uploaded, make sure the permissions of the
    "a" directory are also set.
  - mod_http_upload: Stop correct process name
    Make sure the stop/1 function uses the same process name as the
    start/2 function.
  - Provide an example configuration
* Sun Sep  6 2015 mrueckert@suse.de
- update contrib to c12e225:
  many fixes for mod_mam_mnesia and mod_http_upload
* Thu Aug 20 2015 mrueckert@suse.de
- update to 15.07
  - Message Archive Management (XEP-0313)
  - Add “complete” attribute to MAM final response
  - Fix mod_mam compatibility with RSM
  - Changed mam iq get to set as specified by XEP-0313 v0.3
  - Modules management
  - Ensure config snippet is loaded at module installation
  - Allow contribution to include .yml or .yaml config file
  - Allow include of simple dependencies
  - Multi User Chat
  - New API hook: muc_filter_packet
  - Send notifications on MUC configuration changes
  - Omit warning message regarding non-anonymous room
  - During halt only shutdown MUC rooms on local node
  - Pubsub
  - Allow migration of old pubsub items with old xmlelement
    structure in body
  - Trigger PEP notifications on CAPS updates
  - Check for node subscription of bare JID
  - Flat is now the default plugin
  - Stream Management (XEP-0198)
  - Increase timeout during resumption
  - Increase default “max_ack_queue” value
  - ejabberd Client connection
  - API change: user_send_packet is now a run_fold hook and pass
    the c2s State as a parameter. It was already the case in
    ejabberd 15.06, but it was not mentioned in the changelog, by
    mistake. So, now, you know :)
  - Admin
  - Do not rely on behaviour info when doing config validation,
    so that it can work with ejabberd binary installers
  - When passwords are scrammed, report check_password_hash
    cannot work
  - Fix problem with merging values from multiple config files
  - If local guide.html file not found, redirect to the online
    guide
  - Support RTL page direction in WebAdmin for Hebrew
  - configure.ac: add AC_CONFIG_MACRO_DIR and static AC_INIT
  - WebAdmin
  - Don’t crash web admin when displaying info about websocket
    using users
  - Installers
  - Both RPM and DEB now are using the improved post-install
    script which creates ejabberd user when installing as root.
    This let ejabberd running as user without any manual setup.
  - Windows installer now uses %%USERPROFILE%% to get path of user
    writable directory. We made numerous other fixes to that
    version, thanks to your feedback.
* Wed Aug 19 2015 mrueckert@suse.de
- update contrib to 034a156 and enable mod_http_upload
* Thu Jul  2 2015 mrueckert@suse.de
- disable mod_multicast from the contrib repository
  a) it already is part of core it seems
  b) it installs its own ejabberd_c2s.beam which does  not match
    the new code in 15.06
* Mon Jun 29 2015 mrueckert@suse.de
- update to 15.06 and revision 2a953da of ejabberd-contrib:
  Important update note:
  mod_mam has now 2 implementations: mod_mam and mod_mam_mnesia
  The later is the original mod_mam for ejabberd from the contrib
  repository. The mod_mam that now comes with ejabberd core has
  nothing in common with the old implementation and also does not
  migrate data from mod_mam_mnesia. If you have been using the old
  mod_mam, you might want to switch to mod_mam_mnesia unless you
  need the SQL features that come with the new implementation
  This means you might want to change your config to load
  mod_mam_mnesia *before* updating the package.
  - Message archiving
  - Add support for message archiving in Mnesia or relational
    databases.
  - Protocol
  - Document protocol support and version inside each module and
    use that info in documentation
  - Remove deprecated XEP-0090 Entity Time and XEP-0091 Delayed
    Delivery
  - Don’t add body element to MUC subject messages
  - Do not bounce normal messages sent to unavailable resource
  - Admin command-line tool
  - Fixed several ejabberd commands
  - Allow password with ‘;’ passed in ejabberdctl
  - Improve ejabberdctl external module install code, allows
    better error checking
  - New ping ejabberdctl command to check if the node is up and
    running
  - New commands for Multi-User chat management: get_room_options
    and get_user_rooms
  - Configuration
  - Add config validation at startup
  - Fix include of non yaml config files
  - New option hide_sensitive_log_data to hide client IP address
    in log
  - New option net_ticktime, to fine tune Erlang cluster
    networking
  - New option max_users_presence in mod_muc, to avoid
    broadcasting presence packet from users after a chat room has
    reached a given size
  - Elixir
  - Add correct package version for mix
  - Security
  - New options to configure your own custom Diffie-Helman
    parameters: dhfile and s2s_dhfile
  - PubSub
  - Enforce definition of pubsub node max_items
  - Fix pubsub/odbc crash on remote user unsubscribe
  - Fix use of publish_only affiliation with odbc backend
  - Multicast
  - Pick first local multicast service, otherwise remote
  - Databases
  - Fix anonymous user login, it wasn’t stored in anonymous
    mnesia table
  - Fixed some string/binary issues in ejabberd_odbc
  - PostgreSQL storage: added missing sm (session manager) table
  - Clean up
  - Remove obsolete doc and win32 files
  - Contrib
  - update to 15.06 API changes
* Sat May 23 2015 mrueckert@suse.de
- update contrib to 0.0.0+git1432407478.98ab39f
  - get fixes to build mod_log_chat
* Sat May 23 2015 mrueckert@suse.de
- extend contrib module list a bit: ejabberd_auth_http
  mod_logsession mod_post_log mod_shcommands
* Sat May 23 2015 mrueckert@suse.de
- no longer create /var/lock/ejabberd with tmpfiles.d.
  rather create /run/lock/ejabberdctl that will end up as
  /var/lock/ejabberdctl but will actually allow the build to pass.
* Sat May 23 2015 mrueckert@suse.de
- BR xz for the contrib tarball
- bump BR for erlang to >= 16B3
* Sat May 23 2015 mrueckert@suse.de
- prepared some more features that we can enable once we have the
  buildrequires: riak, redis and sqlite3
* Fri May 22 2015 mrueckert@suse.de
- update to 15.04
  PubSub
    PubSub improvements include code refactor, bug fixes, minor
    optimisations and removal of old mod_pubsub_odbc. mod_pubsub
    now uses db_type parameter like all other ejabberd modules.
    NOTE: Users of old mod_pubsub_odbc will need to alter
    pubsub_node table changing the type attribute: set flat when it
    was flat_odbc, hometree when it was hometree_odbc, and pep when
    it was pep_odbc. Without this manual change in your database,
    the new mod_pubsub will not work.
  - R16B03-1 is now the minimal required Erlang/OTP version
  - SQLite support
  - Default db_type can be specified with global default_db option
  - Included mod_muc_admin, mod_admin_extra and mod_multicast modules
  - Removed ejabberd_http_poll
  - Pubsub improvements
  - Better RFC compliance
  - Several other bugfixes
- integrate ejabberd-contrib and update them to fa47490
  - to split out the contrib modules we need to list all the files
    in ebin/ and the doc dir manually
  - start list with the following modules: mod_admin_extra mod_cron
    mod_logxml mod_mam mod_message_log mod_muc_admin
    mod_muc_log_http mod_multicast mod_rest mod_s2s_log mod_statsdx
    mod_webpresence
- require the main package from the devel package
- cleaned up some old comments in the spec file
- refreshed ejabberd-fix_make_install_when_using_system_deps.patch
* Fri Mar 27 2015 ecsos@opensuse.org
- update to 15.03
  - Add support for WebSocket
  - Flexible session management with multiple backends:
    Mnesia/SQL/Redis or custom backend for session manager
  - Security improvement with SCRAM based password encryption in
    SQL authentication backends.
  - Package management for ejabberd contributed modules
  - Improved Elixir experience
  - Automatic clustering scripts
  - Added missing index on database
  - Important updates on the documentation, with the launch of a
    new documentation site: docs.ejabberd.im
  - Several other bugfixes
* Tue Feb 24 2015 mrueckert@suse.de
- update to 15.02
  - Add Elixir support, allows to write plugins in Elixir
  - New command to reload configuration without restart
  - Support old style erlang expressions in YAML configuration
  - Improved captcha listener parsing when protocol not specified
  - Fix upgrade of old unbinarized pubsub table from 2.1
  - Minor updates in the documentation
  - Other bugfixes
- prepared elixir support but it requires >= 1.1, which is not
  released yet.
  - added conditional to enable it at build time
  - added new requires/buildrequires for elixir
  - added configure option
- refreshed ejabberd-fix_make_install_when_using_system_deps.patch
  to apply cleanly again
* Thu Dec 25 2014 mrueckert@suse.de
- update to 14.12
  includes many bugfixes
  - new features:
  - New module mod_client_state implements XEP-0352: Client State
    Indication
  - New module mod_fail2ban to ban IPs that show malicious signs
  - New option store_empty_body in mod_offline
  - New option disable_sasl_mechanisms
  - Improve option resend_on_timeout to support if_offline
  - Improvements mainly cover:
  - More robust offline server
  - Better charset support in XMLRPC
  - Some PEP issues fixed
- new requires erlang-eHyperLogLog
- refreshed patch
  ejabberd-fix_make_install_when_using_system_deps.patch
* Thu Aug 21 2014 mrueckert@suse.de
- update to 14.07
  - SIP
  - SIP Outbound (RFC 5626) support
  - New option always_record_route
  - New options record_route and routes
  - Carbon Copy (XEP-0280)
  - Don’t log MUC messages with hint
  - Don’t carbon copy messages with hint
  - Let is_carbon_copy/1 recognize carbons
  - Don’t send XEP-0280 v1 copies back to sender
  - Stream Management (XEP-0198)
  - XEP-0198: Terminate session if stanza queue becomes too large
  - XEP-0198: Don’t exit on socket send failure
  - XEP-0198: Don’t drop session on failed resume
  - XEP-0198: Check whether routed packets are stanzas
  - Riak
  - Riak support
  - Install and config
  - New options log_rotate_count, log_rotate_size and
    log_rate_limit
  - html guide is now generated when building source tarball
  - Use p1_utils, and move treap.erl to p1_utils
  - Get rid of p1_mnesia file
  - old release notes are not installed anymore
  - Don’t “forget” listener options
  - Always enable STUN at compile time
  - Do not check for Erlang apps at configure time
  - Add –enable-riak configure flag
  - Tests
  - Add tests for stream management
  - Add tests for mod_carboncopy
  - Add tests for mod_caps
  - Improve MUC test cases
  - Travis CI: Enable Riak tests
  - Add Riak backend to the testing suit
  - The test suite no longer fails without
    –enable-transient_supervisors.
  - MUC
  - MUC messages with ~ were not logged (EJAB-1696).
  And many bugfixes all over the source code.
- new requires andbuildrequires erlang-p1_utils
- dropped 09cb3df3385cdbf0e7e4f6f1edefa613e48aa02a.patch:
  patch was included upstream
- dropped logrotate dependency and configuration. please use the
  new feature within ejabberd.
* Sat Jul  5 2014 mrueckert@suse.de
- added tmpfiles.d config for ejabberd
- clean up systemd/sysV init conditionals
* Sat Jul  5 2014 mrueckert@suse.de
- we should also require the erlang subpackages for runtime
- require erlang-epmd on newer distros
* Sat Jul  5 2014 mrueckert@suse.de
- update to 14.05
  ejabberd now includes support for:
  - XEP-0198: Stream Management (EJAB-532)
  - XEP-0321: Remote Roster Management (EJAB-1381)
  - RFC-3261: SIP proxy/registrar
  - RFC-5766: TURN: Traversal Using Relays around NAT (EJAB-1017)
  There are several improvements regarding encryption:
  - Add option to specify openssl options
  - Fix extraction of host names from certificates
  - Fix certificate authentication for incoming s2s connections
  - Fix handling of certificate verification errors for incoming
    s2s
  - Handle "s2s_use_starttls: required_trusted" the same way for
    outgoing
  - Support certificate verification for outgoing s2s connections
  - Check TLS state before requesting SASL EXTERNAL
  - Log TLS status for outgoing s2s with SASL EXTERNAL
  - Verify host name before offering SASL EXTERNAL
  Just to mention other improvements:
  - New ejabberd command: disconnect_user/2
  - New Bash completion script for ejabberdctl, experimental
    (EJAB-1042)
  - Don't provide current password in webinterface
  - mod_register_web: check same acl as mod_register.
  - Document and enable mod_carboncopy (XEP-0280) by default
  - Make it possible to get/set vCards for MUC rooms
  - Add Travis CI configuration file
- changes from 13.12
  It has several bugfixes over the previous 13.10 release, and a
  few new features:
  - New OpenSSL ciphers option in c2s, s2s and s2s_out
  - mod_roster: new access rule to restrict roster modificartion
  - mod_pubsub: support for data migration from mnesia to odbc
  - ejabberd_xmlrpc included
- changes from 13.10
  The most noticeable changes since 13.03-beta and 13.06 are:
  - in the configuration file: it is now written using YAML syntax
    instead of Erlang syntax. So, after installing ejabberd, search
    for a file called ejabberd.yml. If you have an old
    ejabberd.cfg, you can convert it to yml using the
    “ejabberdctl convert_to_yaml” command. The ejabberd Guide is
    fully updated to describe the new syntax.
  - in logging system: it now uses Lager to produce cleaner logs,
    with a “one line per element” scheme.
  - in build process: now Rebar is used for simpler dependency
    handling, so code is modular among several repositories,
    putting out of ejabberd general purpose libraries.
  Changes since 2.1.13 are even more noticeable:
  - huge improvements regarding performances
  - optimized memory consumption
  - clean code representation of xmlel records
- enable more features
  mysql, pgsql, zlib, stun, json, iconv, http, lager and building
  the tools
- new buildrequires:
  erlang-rebar-obs erlang-esip erlang-ibrowse erlang-jiffy
  erlang-lager erlang-lhttpc erlang-p1_cache_tab erlang-p1_iconv
  erlang-p1_mysql erlang-p1_pam erlang-p1_pgsql erlang-p1_tls
  erlang-p1_stringprep erlang-p1_stun erlang-p1_xml
  erlang-p1_yaml erlang-p1_zlib erlang-xmlrpc
  Those are mostly libraries that used to be intree, but some got
  added for those newly enabled features.
- dropped buildrequires for all the native modules, they are moved
  to the respective erlang-* package now.
- drop patch installuser.patch
  we pass the argument just to the make commandline now
- drop patch ejabberd-cfg.patch:
  replaced with a simple perl -pie
- added 09cb3df3385cdbf0e7e4f6f1edefa613e48aa02a.patch
  patch from matwey to load libraries also from non local
  directories.
- added ejabberd-fix_make_install_when_using_system_deps.patch
  remove the bits from make install that would install files now in
  the dependency packages.
- change service type in the systemd service file to forking
* Fri May  9 2014 matwey.kornilov@gmail.com
- change epmd.socket with epmd.service for compatibility reasons
  in openSUSE < 13.2 we have only /etc/init.d/epmd
    (which is rendered into epmd.service by systemd)
  in openSUSE >= 13.2 we have full systemd support in erlang
* Thu Apr 10 2014 matwey.kornilov@gmail.com
- requires/after epmd.socket in order to start after
  epmd is available
* Sat Jan 11 2014 ecsos@schirra.net
- update to 2.0.13
  * Compilation: Detect correctly newer Darwin versions (EJAB-1594)
  * Guide: ejabberd_service expects a shaper_rule, not a shaper
  * MUC: Handle multiple < and > in mod_muc_log plaintext mode (EJAB-1640)
  * MUC: Handle ~ control sequence in text of mod_muc_log (EJAB-1639)
  * MUC: list_to_integer/2 only works in OTP R14 and newer
  * Pubsub: access_createnode acl also applies to auto created nodes
  * Web: Normalize HTTP path
  * WebAdmin: Fix bug when displaying offline messages in WebAdmin
* Mon Jul  1 2013 chris@computersalat.de
- add build option '--enable-odbc'
- add BuildRequires krb5-devel
- add cfg patch
  * fix captcha script path
- fix permission on captcha script
- fix deps
  * add missing 'gs' needed by captcha
* Sun Jun  2 2013 wr@rosenauer.org
- address some rpmlint warnings
  * fix empty postinst
  * added rpmlint filters for expected warnings
  * added su option to logrotate definition
- create user and group as required by packaging guidelines
- clean up SysV and systemd support
* Sat Jun  1 2013 wr@rosenauer.org
- set enable-user to the system user to make ejabberctl work
  as root correctly as well
  * skip installation as system user via installuser.patch
* Wed May 22 2013 wr@rosenauer.org
- update to 2.1.12
  [EJAB-405] - If error occurs in stream setting, it must still open
    stream tag
  [EJAB-1053] - Change installation paths in Windows
  [EJAB-1408] - pubsub_state#items not updated for other publishers
    of the node
  [EJAB-1563] - LDAP Connection Broken with 2.1.11 (32 bit)
  [EJAB-1566] - On shutdown, first stop listeners, then modules
  [EJAB-1572] - Check node name is available before starting ejabberd
  [EJAB-1578] - Pidgin client digest-uri checks fail with virtual hosts
  [EJAB-1580] - windows service of ejabberd 2.1.11 doesn't work
  [EJAB-1599] - [patch included] ejabberd leaks hundreds of mysql
    connections if database mistyped/
  [EJAB-1606] - Update copyright to 2013
  [EJAB-1610] - Fix angle brackets handle in MUC plaintext log
  [EJAB-1611] - Support different node names and different NIC IP
    address on the same box
  [EJAB-1612] - Fix compatibility of LDAP support with Erlang R16A
  [EJAB-1626] - Fail to build from source
  [EJAB-984] - Windows ejabberd service
  [EJAB-1020] - Choice of user shortcuts
  [EJAB-1081] - Windows Installer unexpected behaviors
  [EJAB-1082] - Doc fixes & suggestions
  [EJAB-1560] - Merge Mnesia and ODBC code into one file
  [EJAB-1567] - Let Windows installer bring up dependencies
  [EJAB-1588] - umask option for mod_muc_log
* Wed Dec 12 2012 highwaystar.ru@gmail.com
- systemd unit added
- changelog removed from spec file
* Thu Sep 27 2012 mrueckert@suse.de
- epmd should be started by the seperate epmd init script and not
  by ejabberd. require the epmd service in the init script.
- remove remaining part of the sample description in the lsb header
* Wed Sep 26 2012 mrueckert@suse.de
- update to 2.1.11
  [EJAB-1294] - Doesn't return user affiliation for a specified
  node.
  [EJAB-1504] - Persistent startup failure on OS X Lion
  [EJAB-1509] - Foreign shared rosters items not pushed
  [EJAB-1524] - 32bit linux installer includes old ssl/crypto
  0.9.7 libs, and break driver compatibility
  [EJAB-1527] - R15B Lion 10.7.2, Binary Version of 2.1.10: run
  'ejabberdctl live' ERROR
  [EJAB-1529] - ejabberd's interpretation of digest-uri causes
  Pidgin to fail authorization
  [EJAB-1530] - http_bind webserver TLS fail on Chrome
  [EJAB-1537] - Ejabberd http-bind over tls has issues with
  browsers
  [EJAB-1538] - HTTP HEAD calls give "HTTP/1.0 400 Bad Request"
  on http-bind
  [EJAB-1539] - Pubsub notifications should be sent after a
  result iq
  [EJAB-1553] - stop_kindly command crashes if MUCs are not
  running, leaving ejabberd without listeners
  [EJAB-1554] - Photos from LDAP not displayed in some clients,
  lacking TYPE
  [EJAB-1569] - Ejabberd crashes after a few minutes of operation
  [EJAB-1261] - Option default_host for handling HTTP requests
  with ambiguous Host
  [EJAB-1555] - pattern variable substitutions in ldap_rfilter
- pass --enable-nif to configure
  Tue Jan 10 7:39:52 UTC 2012 - harland.coles
- updated to 2.1.10
  * Erlang/OTP compatibility
  * Support Erlang/OTP R15B regexp and drivers (EJAB-1521)
  * Fix modules update in R14B04 and higher
  * Fix modules update of stripped beams (EJAB-1520)
  * Core: Fix presence problem in C2S after first unavailable (EJAB-1466)
  * Core: Fix bug on S2S shaper when TLS is used
  * Core: Prevent overload of incoming S2S connections
  * XEPs
  * BOSH: Get rid of useless mnesia transaction (EJAB-1502)
  * MUC: Don't reveal invitee resource when room informs invitor
  * Privacy: Activate "Blocked Contacts" to current c2s connection (EJAB-1519)
  * Privacy: Always allow packets from user's server and bare jid (EJAB-1441)
  * Pubsub: Add hooks for node creation/deletion (EJAB-1470)
  * Shared Rosters: support groupname@vhost in Displayed Groups (EJAB-506)
  * Vcard: Fix error when lowercasing some search results (EJAB-1490)
* Wed Jul 27 2011 highwaystar.ru@gmail.com
- updated to 2.1.8
  * fixed PubSub broken in 2.1.7
- changes in 2.1.7
  * fix DoS attack trough entity expansion (CVE-2011-1753)
  * BOSH: Keep the order of stanzas when BOSH sends several (EJAB-1374)
  * CAPTCHA in MUC: New whitelist option
  * CAPTCHA: New captcha_limit option
  * Core: Disable all entity expansions (EJAB-1451)
  * Core: Do not accept XML with undefined prefixes (EJAB-680)
  * ejabberdctl: New DIST_USE_INTERFACE restricts IP erlang listen (EJAB-1404)
  * ejabberdctl: New ERL_EPMD_ADDRESS that works since Erlang/OTP R14B03
  * extauth: If script crashes, ejabberd should restart it (EJAB-1428)
  * If a module start fails during server start, stop erlang (EJAB-1446)
  * mod_blocking: New XEP-0191 Simple Communications Blocking (EJAB-695)
  * mod_pres_counter: Prevent subscription flood (EJAB-1388)
  * mod_register: Access now also controls account unregistrations
  * mod_shared_roster: Fix support for anonymous accounts in @all@ (EJAB-1264)
  * mod_shared_roster: New @online@ directive (EJAB-1391)
  * New Indonesian translation (EJAB-1407)
  * Pubsub: Apply filtered notification to PEP last items (EJAB-1456)
  * Pubsub: Owner can delete any items from its own node (EJAB-1445)
* Wed Dec 22 2010 highwaystar.ru@gmail.com
- updated to 2.1.6
  * BOSH: Fix rare loop, support vhosts, allow module restart
  * Config: Default configuration allows registrations only from localhost
  * Config: Support to change loglevel per module at runtime
  * Erlang/OTP: Fix compatibility from R10B-9 to R14B01
  * ODBC: Compatibility with PostgreSQL 9.0
  * Privacy lists: Fix to allow block by group and subscription again
  * Pubsub: Fix cross domain eventing
  * Register: Added CAPTCHA, password strength and ip_access to mod_register
  * Register: New mod_register_web, with CAPTCHA support
  * S2S: New options to require encryption, and verify certificates
  * Shared Rosters: Added mod_shared_roster_ldap
  * Bind listener ports early and start accepting connections later
- removed EJAB-1285 patch, now upstream
* Sun Aug 15 2010 highwaystar.ru@gmail.com
- updated to 2.1.5
  * Erlang/OTP R12 support fixed
  * Erlang/OTP R14A support added
  * OpenSSL 0.9.8 or higher is required
  * BOSH: New optional connection attribute process-delay
  * C2S: Don't ask for client certificate when using tls
  * C2S: Inform client that SSL session caching is disabled
- added patch for optionam md2 (EJAB-1285)
- fixed rpm group
- fixed /var/lock/ejabberdctl dir
* Tue Jun 29 2010 highwaystar.ru@gmail.com
- updated to 2.1.4
- Fourth bugfix release
  * Bounce messages when closing c2s session
  * Bugfixes when handling Service Discovery to contacts
  * Don't send error stanza as reply to error stanza
  * Don't store blocked messages in offline queue
  * Extauth: Optionally cache extauth users in mnesia
  * Full support for XEP-0115 Entity Capabilities v1.5
  * HTTP-Bind (BOSH): Remove unneeded 100 ms delay, and export functions to facilitate prebinding methods
* Wed Mar 17 2010 highwaystar.ru@gmail.com
- updated to 2.1.3
- third bugfix release
  * New ejabberd_c2s option: max_fsm_queue
  * ejabberdctl: Support concurrent connections with bound connection names
  * Cross-domain HTTP-Bind support (EJAB-1168)
  * Hibernate http-bind process after handling a request
* Wed Jan 20 2010 highwaystar.ru@gmail.com
- updated to 2.1.2
- bugfix release
  * Fix SASL PLAIN authentication message for RFC4616 compliance
  * Fix support for old Erlang/OTP R10 and R11
  * If server start fails due to config file problem, display some lines and stop node
  * PubSub and PEP: several improvements and bugfixes
  * WebAdmin: fix offline message displaying
  * When server stops with new stop_kindly command: inform users, clients, MUC
* Thu Jan  7 2010 highwaystar.ru@gmail.com
- updated to 2.1.1
- bugfix release
  * Fix connection if starttls_required and zlib are set
  * S2S: fix allow_host/2 on subdomains. added hook s2s_allow_host
  * MUC: Add support for serving a Unique Room Name
  * MUC: Route vCard request to the occupant bare JID
  * MUC: Support converting one-to-one chat to MUC
  * PubSub: Receive same last published PEP items at reconnect if several resources online
  * PubSub: Typo in mod_pubsub_odbc breaks Service Discovery and more
  * Web: Fix memory and port leak when TLS is enabled in HTTP
  * WebAdmin: report correct last activity with odbc backends
  * Change captcha.sh to not depend on bash
  * Generate main XML file also when exporting only a vhost
  * Fix last newline in ejabberdctl result
  * Guide: fix -setcookie, mod_pubsub_odbc host, content_types
* Sat Nov 14 2009 highwaystar.ru@gmail.com
- finaly updated to 2.1.0
  * Erlang/OTP R13 support
  * HTTP-Bind (BOSH) optimization and clean-up
  * LDAPS support
  * MUC rooms can require a CAPTCHA to join the room
  * PubSub: major improvements. Update to XEP version 1.12
  * PEP and Caps: many improvements
  * Run commands with ejabberdctl or other frontends (XML-RPC, HTTP)
  * STUN server
  * XEPs like: XMPP Ping, Roster Versioning, Import/Export Format
* Mon Oct 26 2009 highwaystar.ru@gmail.com
- updated to 2.1.0 rc2
* Sat Sep 26 2009 highwaystar.ru@gmail.com
- updated to 2.1.0rc1
- global spec cleaning
- using ejabberd.cfg and inetrc from ejabberd tarball
- removed latex from buildreq as pdfs now shipped in tarball
- removed old hacks patches.
- added ImageMagick to Requires for CAPTCHA support
* Thu Sep 17 2009 highwaystar.ru@gmail.com
- patched with dynamic_compile_loglevel.patch to make run it with Erlang R13B
* Mon Jul 20 2009 highwaystar.ru@gmail.com
- updated to version 2.0.5
- spec file cleanup (removed useless lines)
- package project cleanup (removed old sources)
- added suse postun preun
* Thu Feb  5 2009 alex@simonov.in.ua
- Version bump to 2.0.3
- Fix /usr/sbin/ejabberdctl
- Run ejabberd under ejabberd user
* Fri Aug 29 2008 cyberorg@opensuse.org
- Update to 2.0.0
- Apply OLPC patches
* Wed Nov  1 2006 peter+rpmspam@suntel.com.tr
- Create a spec for openSUSE
